@@ -7,7 +7,7 @@ Attean::API::Iterator - Typed iterator
 
 =head1 VERSION
 
-This document describes Attean::API::Iterator version 0.034
+This document describes Attean::API::Iterator version 0.001
 
 =head1 DESCRIPTION
 
@@ -92,49 +92,60 @@ C<< $limit >> elements of the referent.
 Returns a new L<Attean::API::RepeatableIterator> object containing all the
 elements from the referent.
 
+=back
+
 =cut
 
-package Attean::API::Iterator 0.034 {
+package Attean::API::Iterator 0.001 {
+	use Moo::Role;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Str Object InstanceOf);
-	use Carp qw(confess);
-
-	use Moo::Role;
+	use Role::Tiny;
+	use namespace::clean;
 	
 	has 'item_type' => (is => 'ro', isa => Str, required => 1);
 	requires 'next';
 
+# TODO: remove	
+	around BUILDARGS => sub {
+		my $orig	= shift;
+		my $self	= shift;
+		my $args	= $self->$orig(@_);
+		use Data::Dumper;
+		my $type	= $args->{item_type};
+		if (ref($type)) {
+			Carp::cluck Dumper($type);
+		}
+		return $args;
+	};
+	
 	sub BUILD {}
 	around 'BUILD' => sub {
 		my $orig	= shift;
 		my $self	= shift;
-		my $args	= shift;
-		$self->$orig($args);
+		$self->$orig(@_);
 		my $role	= $self->item_type;
-		if (Moo::Role->is_role($role)) {
+		if (Role::Tiny->is_role($role)) {
 			my $check	= sub {
 				my $check = shift;
-				return ($role eq $check or Moo::Role::does_role($role, $check));
+				return ($role eq $check or Role::Tiny::does_role($role, $check));
 			};
 			if ($check->('Attean::API::Quad')) {
-				Moo::Role->apply_roles_to_object($self, 'Attean::API::QuadIterator');
+				Role::Tiny->apply_roles_to_object($self, 'Attean::API::QuadIterator');
 			} elsif ($check->('Attean::API::Triple')) {
-				Moo::Role->apply_roles_to_object($self, 'Attean::API::TripleIterator');
+				Role::Tiny->apply_roles_to_object($self, 'Attean::API::TripleIterator');
 			} elsif ($check->('Attean::API::TripleOrQuad')) {
-				Moo::Role->apply_roles_to_object($self, 'Attean::API::MixedStatementIterator');
+				Role::Tiny->apply_roles_to_object($self, 'Attean::API::MixedStatementIterator');
 			} elsif ($check->('Attean::API::Result')) {
-				Moo::Role->apply_roles_to_object($self, 'Attean::API::ResultIterator');
-				my $vars	= $args->{variables} // confess "Construction of a Attean::API::ResultIterator must include a variables list";
-				$self->variables($vars);
+				Role::Tiny->apply_roles_to_object($self, 'Attean::API::ResultIterator');
 			} elsif ($check->('Attean::API::Term')) {
-				Moo::Role->apply_roles_to_object($self, 'Attean::API::TermIterator');
+				Role::Tiny->apply_roles_to_object($self, 'Attean::API::TermIterator');
 			} elsif ($check->('Attean::API::ResultOrTerm')) {
-				Moo::Role->apply_roles_to_object($self, 'Attean::API::ResultOrTermIterator');
-				$self->variables($args->{variables} || []);
+				Role::Tiny->apply_roles_to_object($self, 'Attean::API::ResultOrTermIterator');
 			}
 
 			if ($self->does('Attean::API::RepeatableIterator') and $check->('Attean::API::Binding')) {
-				Moo::Role->apply_roles_to_object($self, 'Attean::API::CanonicalizingBindingSet');
+				Role::Tiny->apply_roles_to_object($self, 'Attean::API::CanonicalizingBindingSet');
 			}
 		}
 	};
@@ -147,10 +158,8 @@ package Attean::API::Iterator 0.034 {
 			my $class	= ref($self);
 			my $term	= $self->$orig(@_);
 			return unless defined($term);
-			if (blessed($term)) {
-				unless ($term->does($type) or $term->isa($type)) {
-					die "${class} returned an element that failed conformance check for $type: $term";
-				}
+			unless ($term->does($type)) {
+				die "${class} returned an element that failed conformance check for $type";
 			}
 			return $term;
 		};
@@ -189,27 +198,14 @@ package Attean::API::Iterator 0.034 {
 			}
 		}
 		
-		# copy variables into new iterator if $self does ::ResultIterator or ::ResultOrTermIterator
-		my %args	= @_;
-		if ($self->can('variables') and not exists $args{variables}) {
-			$args{variables}	= $self->variables;
-		}
-		
-		return Attean::CodeIterator->new( %args, item_type => $type, generator => $generator );
+		return Attean::CodeIterator->new( item_type => $type, generator => $generator );
 	}
 
 	sub grep {
 		my $self	= shift;
 		my $block	= shift;
 		
-		# copy variables into new iterator if $self does ::ResultIterator or ::ResultOrTermIterator
-		my %args	= @_;
-		if ($self->can('variables') and not exists $args{variables}) {
-			$args{variables}	= $self->variables;
-		}
-		
 		Attean::CodeIterator->new(
-			%args,
 			item_type => $self->item_type,
 			generator => sub {
 				while (1) {
@@ -233,14 +229,7 @@ package Attean::API::Iterator 0.034 {
 		my $self	= shift;
 		my $limit	= shift;
 		
-		# copy variables into new iterator if $self does ::ResultIterator or ::ResultOrTermIterator
-		my %args	= @_;
-		if ($self->can('variables') and not exists $args{variables}) {
-			$args{variables}	= $self->variables;
-		}
-		
 		Attean::CodeIterator->new(
-			%args,
 			item_type => $self->item_type,
 			generator => sub {
 				return unless $limit;
@@ -255,20 +244,9 @@ package Attean::API::Iterator 0.034 {
 	sub materialize {
 		my $self	= shift;
 		my @data	= $self->elements;
-		my %args	= @_;
-		if ($self->can('variables') and not exists $args{variables}) {
-			$args{variables}	= $self->variables;
-		}
-		
-		return Attean::ListIterator->new( %args, values => \@data, item_type => $self->item_type );
+		return Attean::ListIterator->new( values => \@data, item_type => $self->item_type );
 	}
 	
-=item C<< debug( [$name] ) >>
-
-Print each item as it is consumed (with the string generated by C<< as_string >>), prepended by C<< $name >>.
-
-=cut
-
 	sub debug {
 		my $self	= shift;
 		my $name	= shift // 'Iterator item';
@@ -276,20 +254,7 @@ Print each item as it is consumed (with the string generated by C<< as_string >>
 	}
 }
 
-package Attean::API::StringyItemIterator 0.034 {
-	use Moo::Role;
-	sub uniq {
-		my $self	= shift;
-		
-		my %seen;
-		return $self->grep(sub {
-			my $r	= shift;
-			return not($seen{ $r->as_string }++);
-		});
-	}
-}
-
-package Attean::API::RepeatableIterator 0.034 {
+package Attean::API::RepeatableIterator 0.001 {
 	use Moo::Role;
 	requires 'reset';
 	
@@ -313,12 +278,6 @@ package Attean::API::RepeatableIterator 0.034 {
 		return $self;
 	}
 
-	sub size {
-		my $self	= shift;
-		my @elements	= $self->elements;
-		return scalar(@elements);
-	}
-	
 	with 'Attean::API::Iterator';
 }
 
@@ -331,12 +290,8 @@ package Attean::API::CanonicalizingBindingIterator {
 	}
 }
 
-package Attean::API::ResultOrTermIterator 0.034 {
+package Attean::API::ResultOrTermIterator 0.001 {
 	use Moo::Role;
-	use Types::Standard qw(ArrayRef Str);
-	has 'variables' => (is => 'rw', isa => ArrayRef[Str], default => sub { [] });
-	with 'Attean::API::StringyItemIterator';
-	
 	sub canonicalize {
 		my $self	= shift;
 		my $mapper	= Attean::TermMap->canonicalization_map;
@@ -350,85 +305,26 @@ package Attean::API::ResultOrTermIterator 0.034 {
 			}
 		});
 	}
-	
-	around 'grep' => sub {
-		my $orig	= shift;
-		my $self	= shift;
-		my $block	= shift;
-		my $iter	= $orig->($self, $block, @_);
-		Attean::CodeIterator->new(
-			item_type => $iter->item_type,
-			generator => sub {
-				return $iter->next();
-			},
-			variables => $self->variables,
-		);
-	};
 }
 
-package Attean::API::StatementIterator 0.034 {
-	use Moo::Role;
-	use Scalar::Util qw(blessed);
-	with 'Attean::API::StringyItemIterator';
-	requires 'variables';
-
-	sub matching_pattern {
-		my $self	= shift;
-		my @nodes	= @_;
-		
-		if (scalar(@nodes) == 1 and $nodes[0]->does('Attean::API::QuadPattern')) {
-			my $pattern	= $nodes[0];
-			@nodes	= $pattern->values;
-		}
-
-		my %bound;
-		my @pos_names	= $self->variables;
-		foreach my $pos (0 .. $#pos_names) {
-			my $n	= $nodes[ $pos ];
-			if (blessed($n)) {
-				$bound{ $pos_names[$pos] }	= $n;
-			}
-		}
-		
-		my $pattern	= Attean::QuadPattern->new( %bound );
-		return $self->grep(sub {
-			my $q	= shift;
-			my $binding	= $pattern->unify($q);
-			return $binding ? 1 : 0;
-		});
-	}
-}
-
-package Attean::API::TripleIterator 0.034 {
+package Attean::API::TripleIterator 0.001 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
-	with 'Attean::API::StatementIterator';
-
 	sub as_quads {
 		my $self	= shift;
 		my $graph	= shift;
 		return $self->map(sub { $_->as_quad($graph) }, 'Attean::API::Quad');
 	}
-
-	sub variables {
-		return qw(subject predicate object);
-	}
 }
 
-package Attean::API::QuadIterator 0.034 {
+package Attean::API::QuadIterator 0.001 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
-	with 'Attean::API::StatementIterator';
-	
-	sub variables {
-		return qw(subject predicate object graph);
-	}
 }
 
-package Attean::API::MixedStatementIterator 0.034 {
+package Attean::API::MixedStatementIterator 0.001 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
-	with 'Attean::API::StringyItemIterator';
 	sub as_quads {
 		my $self	= shift;
 		my $graph	= shift;
@@ -439,18 +335,12 @@ package Attean::API::MixedStatementIterator 0.034 {
 	}
 }
 
-package Attean::API::ResultIterator 0.034 {
-	use Types::Standard qw(Str ArrayRef);
+package Attean::API::ResultIterator 0.001 {
 	use Moo::Role;
-	
 	with 'Attean::API::CanonicalizingBindingIterator';
-	with 'Attean::API::StringyItemIterator';
-	has 'variables' => (is => 'rw', isa => ArrayRef[Str], required => 1);
 	sub join {
 		my $self	= shift;
 		my $rhs		= shift;
-		my @vars	= keys %{ { map { $_ => 1 } (@{ $self->variables }, @{ $rhs->variables }) } };
-		
 		my @rhs		= $rhs->elements;
 		my @results;
 		while (my $lhs = $self->next) {
@@ -460,13 +350,11 @@ package Attean::API::ResultIterator 0.034 {
 				}
 			}
 		}
-		return Attean::ListIterator->new( values => \@results, item_type => $self->item_type, variables => \@vars);
+		return Attean::ListIterator->new( values => \@results, item_type => $self->item_type);
 	}
-
-	with 'Attean::API::ResultOrTermIterator';
 }
 
-package Attean::API::TermIterator 0.034 {
+package Attean::API::TermIterator 0.001 {
 	use Moo::Role;
 	sub canonicalize {
 		my $self	= shift;
@@ -474,36 +362,12 @@ package Attean::API::TermIterator 0.034 {
 		return $self->map( $mapper );
 	}
 	with 'Attean::API::CanonicalizingBindingIterator';
-	with 'Attean::API::StringyItemIterator';
 }
 
 1;
 
 __END__
 
-=back
-
-=head2 Methods on Roles Supporting Stringification
-
-For iterators over roles that provide an C<as_string> method, extra methods
-are provided. These iterators are:
-
-Attean::API::ResultOrTermIterator
-Attean::API::StatementIterator
-Attean::API::MixedStatementIterator
-Attean::API::ResultIterator
-Attean::API::TermIterator
-
-They provide the following methods:
-
-=over 4
-
-=item C<< uniq >>
-
-Returns a new iterator providing unique results (based on the stringified value of the underlying elements).
-
-=back
-
 =head1 BUGS
 
 Please report any bugs or feature requests to through the GitHub web interface
@@ -513,7 +377,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 L<Attean::API::RepeatableIterator>
 
-
+L<http://www.perlrdf.org/>
 
 =head1 AUTHOR
 
@@ -521,7 +385,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams.
+Copyright (c) 2014 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
