@@ -7,7 +7,7 @@ Attean::API::Parser - Parser role
 
 =head1 VERSION
 
-This document describes Attean::API::Parser version 0.033
+This document describes Attean::API::Parser version 0.001
 
 =head1 DESCRIPTION
 
@@ -48,119 +48,36 @@ to this parser.
 Returns a L<Type::Tiny> object representing the type of items that result from
 parsing.
 
-=item C<< file_extensions >>
-
-Returns an ARRAY reference of file extensions commonly associated with the
-media types supported by the parser (and returned by C<< media_types >>).
-File extensions should NOT include a leading dot.
-
 =cut
 
 use Type::Tiny::Role;
 
-package Attean::API::Parser 0.033 {
-	use Types::Standard qw(CodeRef Bool);
-
+package Attean::API::Parser 0.001 {
 	use Moo::Role;
-	use Scalar::Util qw(blessed);
+	use Types::Standard qw(CodeRef);
 	use namespace::clean;
 	
 	has 'handler' => (is => 'rw', isa => CodeRef, default => sub { sub {} });
-	has 'lazy_iris' => (is => 'rw', isa => Bool, default => 0);
 	
 	requires 'canonical_media_type'; # => (is => 'ro', isa => 'Str', init_arg => undef);
 	requires 'media_types'; # => (is => 'ro', isa => 'ArrayRef[Str]', init_arg => undef);
 	requires 'handled_type'; # => (is => 'ro', isa => 'Type::Tiny', init_arg => undef);
 	requires 'file_extensions'; # => (is => 'ro', isa => 'ArrayRef[Str]', init_arg => undef);
-	
-=item C<< new_iri( value => $value ) >>
-
-Constructs and returns a new L<Attean::IRI> object, respecting the parser's
-C<lazy_iris> attribute.
-=cut
-
-	sub new_iri {
-		my $self	= shift;
-		my %args;
-		if ($self->lazy_iris) {
-			$args{lazy}	= 1;
-		} else {
-			$args{lazy}	= 0;
-		}
-		if (scalar(@_) == 1) {
-			$args{value}	= shift;
-		} else {
-			%args	= (%args, @_);
-		}
-		return Attean::IRI->new(%args);
-	}
-
-=item C<< new_literal( value => $value, [ datatype => $dt, ] [ language => $lang ])	>>
-
-Constructs and returns a new L<Attean::Literal> object.
-
-=cut
-
-	sub new_literal {
-		my $self	= shift;
-		my %args	= @_;
-		
-		return Attean::Literal->new(%args);
-	}
-	
-	sub file_extensions { return [] }
 }
 
-package Attean::API::AbbreviatingParser 0.033 {
-	use Types::Standard qw(ConsumerOf InstanceOf Maybe);
-	use Types::Namespace qw( NamespaceMap );
-	use Scalar::Util qw(blessed);
-
+package Attean::API::AbbreviatingParser 0.001 {
 	use Moo::Role;
+	use Types::Standard qw(InstanceOf Maybe);
+	use URI::NamespaceMap;
+	use Scalar::Util qw(blessed);
+	use namespace::clean;
 	
 	with 'Attean::API::Parser';
-	has 'base' 			=> (is => 'rw', isa => ConsumerOf['Attean::API::IRI'], coerce => sub { blessed($_[0]) ? Attean::IRI->new($_[0]->as_string) : Attean::IRI->new($_[0]) }, predicate => 'has_base');
-	has 'namespaces'	=> (is => 'ro', isa => Maybe[NamespaceMap]);
+	has 'base' 		=> (is => 'rw', isa => InstanceOf['IRI'], coerce => sub { blessed($_[0]) ? IRI->new($_[0]->as_string) : IRI->new($_[0]) }, predicate => 'has_base');
+	has 'namespaces'	=> (is => 'ro', isa => Maybe[InstanceOf['URI::NamespaceMap']]);
 }
 
-package Attean::API::CDTBlankNodeMappingParser 0.033 {
-	use Types::Standard qw(HashRef ConsumerOf InstanceOf Maybe Bool);
-	use Scalar::Util qw(blessed);
-	use UUID::Tiny ':std';
-	use Data::Dumper;
-	use Moo::Role;
-	
-	with 'Attean::API::Parser';
-	has 'blank_nodes'	=> (is => 'ro', isa => Maybe[HashRef[ConsumerOf['Attean::API::Blank']]]);
-	has 'parse_id'		=> (is => 'rw', default => sub { unpack('H*', create_uuid()) });
-	has 'enable_cdt_rewriting' => (is => 'rw', isa => Bool, default => 1);
-
-	foreach my $method (qw(parse_iter_from_io parse_iter_from_bytes parse_cb_from_io parse_cb_from_bytes)) {
-		around $method => sub {
-			my $orig	= shift;
-			my $self	= $_[0];
-
-			$self->parse_id(unpack('H*', create_uuid()));
-			my $term	= $orig->(@_);
-			return $term;
-		};
-	}
-	
-	around 'new_literal' => sub {
-		my $orig	= shift;
-		my $self	= $_[0];
-		my $term	= $orig->(@_);
-		if ($self->enable_cdt_rewriting) {
-			my $dt 		= $term->datatype();
-			if (blessed($dt) and ($dt->value eq 'http://w3id.org/awslabs/neptune/SPARQL-CDTs/Map' or $dt->value eq 'http://w3id.org/awslabs/neptune/SPARQL-CDTs/List')) {
-				return AtteanX::Functions::CompositeLists::rewrite_lexical($term, $self->blank_nodes, $self->parse_id);
-			}
-		}
-		return $term;
-	};
-}
-
-package Attean::API::PushParser 0.033 {
+package Attean::API::PushParser 0.001 {
 	use Moo::Role;
 	with 'Attean::API::Parser';
 
@@ -170,37 +87,13 @@ package Attean::API::PushParser 0.033 {
 	sub parse_iter_from_io {
 		my $self	= shift;
 		my @values	= $self->parse_list_from_io(@_);
-		if ($self->does('Attean::API::ResultParser') or $self->does('Attean::API::ResultOrTermParser')) {
-			my %vars;
-			foreach my $r (@values) {
-				if ($r->does('Attean::API::Result')) {
-					foreach my $v ($r->variables) {
-						$vars{$v}++;
-					}
-				}
-			}
-			return Attean::ListIterator->new( variables => [keys %vars], values => \@values, item_type => $self->handled_type->role, );
-		} else {
-			return Attean::ListIterator->new( values => \@values, item_type => $self->handled_type->role, );
-		}
+		return Attean::ListIterator->new( values => \@values, item_type => $self->handled_type->role, );
 	}
 	
 	sub parse_iter_from_bytes {
 		my $self	= shift;
 		my @values	= $self->parse_list_from_bytes(@_);
-		if ($self->does('Attean::API::ResultParser') or $self->does('Attean::API::ResultOrTermParser')) {
-			my %vars;
-			foreach my $r (@values) {
-				if ($r->does('Attean::API::Result')) {
-					foreach my $v ($r->variables) {
-						$vars{$v}++;
-					}
-				}
-			}
-			return Attean::ListIterator->new( variables => [keys %vars], values => \@values, item_type => $self->handled_type->role, );
-		} else {
-			return Attean::ListIterator->new( values => \@values, item_type => $self->handled_type->role, );
-		}
+		return Attean::ListIterator->new( values => \@values, item_type => $self->handled_type->role, );
 	}
 	
 	sub parse_list_from_io {
@@ -224,7 +117,7 @@ package Attean::API::PushParser 0.033 {
 	}
 }
 
-package Attean::API::PullParser 0.033 {
+package Attean::API::PullParser 0.001 {
 	use Moo::Role;
 	with 'Attean::API::Parser';
 	
@@ -266,7 +159,7 @@ package Attean::API::PullParser 0.033 {
 	}
 }
 
-package Attean::API::AtOnceParser 0.033 {
+package Attean::API::AtOnceParser 0.001 {
 	use Moo::Role;
 	with 'Attean::API::Parser';
 	
@@ -292,42 +185,18 @@ package Attean::API::AtOnceParser 0.033 {
 	sub parse_iter_from_io {
 		my $self	= shift;
 		my @values	= $self->parse_list_from_io(@_);
-		if ($self->does('Attean::API::ResultParser') or $self->does('Attean::API::ResultOrTermParser')) {
-			my %vars;
-			foreach my $r (@values) {
-				if ($r->does('Attean::API::Result')) {
-					foreach my $v ($r->variables) {
-						$vars{$v}++;
-					}
-				}
-			}
-			return Attean::ListIterator->new( variables => [keys %vars], values => \@values, item_type => $self->handled_type->role, );
-		} else {
-			return Attean::ListIterator->new( values => \@values, item_type => $self->handled_type->role, );
-		}
+		return Attean::ListIterator->new( values => \@values, item_type => $self->handled_type->role, );
 	}
 	
 	sub parse_iter_from_bytes {
 		my $self	= shift;
 		my @values	= $self->parse_list_from_bytes(@_);
-		if ($self->does('Attean::API::ResultParser') or $self->does('Attean::API::ResultOrTermParser')) {
-			my %vars;
-			foreach my $r (@values) {
-				if ($r->does('Attean::API::Result')) {
-					foreach my $v ($r->variables) {
-						$vars{$v}++;
-					}
-				}
-			}
-			return Attean::ListIterator->new( variables => [keys %vars], values => \@values, item_type => $self->handled_type->role, );
-		} else {
-			return Attean::ListIterator->new( values => \@values, item_type => $self->handled_type->role, );
-		}
+		return Attean::ListIterator->new( values => \@values, item_type => $self->handled_type->role, );
 	}
 	
 }
 
-package Attean::API::TermParser 0.033 {
+package Attean::API::TermParser 0.001 {
 	# Parser returns objects that conform to Attean::API::Term
 	use Moo::Role;
 	with 'Attean::API::Parser';
@@ -337,7 +206,7 @@ package Attean::API::TermParser 0.033 {
 	}
 }
 
-package Attean::API::TripleParser 0.033 {
+package Attean::API::TripleParser 0.001 {
 	# Parser returns objects that conform to Attean::API::Triple
 	use Moo::Role;
 	with 'Attean::API::Parser';
@@ -347,7 +216,7 @@ package Attean::API::TripleParser 0.033 {
 	}
 }
 
-package Attean::API::QuadParser 0.033 {
+package Attean::API::QuadParser 0.001 {
 	# Parser returns objects that conform to Attean::API::Quad
 	use Moo::Role;
 	with 'Attean::API::Parser';
@@ -357,7 +226,7 @@ package Attean::API::QuadParser 0.033 {
 	}
 }
 
-package Attean::API::MixedStatementParser 0.033 {
+package Attean::API::MixedStatementParser 0.001 {
 	# Parser returns objects that conform to either Attean::API::Triple or Attean::API::Quad
 	use Moo::Role;
 	with 'Attean::API::Parser';
@@ -367,7 +236,7 @@ package Attean::API::MixedStatementParser 0.033 {
 	}
 }
 
-package Attean::API::ResultOrTermParser 0.033 {
+package Attean::API::ResultOrTermParser 0.001 {
 	# Parser returns objects that conform to either Attean::API::Result or Attean::API::Term
 	use Moo::Role;
 	with 'Attean::API::Parser';
@@ -377,7 +246,7 @@ package Attean::API::ResultOrTermParser 0.033 {
 	}
 }
 
-package Attean::API::ResultParser 0.033 {
+package Attean::API::ResultParser 0.001 {
 	# Parser returns objects that conform to Attean::API::Result
 	use Moo::Role;
 	with 'Attean::API::Parser';
@@ -400,7 +269,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-
+L<http://www.perlrdf.org/>
 
 =head1 AUTHOR
 
@@ -408,7 +277,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams.
+Copyright (c) 2014 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
