@@ -7,7 +7,7 @@ Attean::API::Serializer - Serializer role
 
 =head1 VERSION
 
-This document describes Attean::API::Serializer version 0.034
+This document describes Attean::API::Serializer version 0.001
 
 =head1 DESCRIPTION
 
@@ -34,18 +34,12 @@ produced by this serializer.
 Returns a L<Type::Tiny> object representing the type of items that are consumed
 during serialization.
 
-=item C<< file_extensions >>
-
-Returns an ARRAY reference of file extensions commonly associated with the
-media types supported by the serializer (and returned by C<< media_types >>).
-File extensions should NOT include a leading dot.
-
 =item C<< serialize_iter_to_io( $fh, $iterator ) >>
 
 Serializes the elements from the L<Attean::API::Iterator> C<< $iterator >> to
 the L<IO::Handle> object C<< $fh >>.
 
-=item C<< serialize_iter_to_bytes( $fh ) >>
+=item C<< serialize_iter_to_bytes( $fh, $iterator ) >>
 
 Serializes the elements from the L<Attean::API::Iterator> C<< $iterator >>
 and returns the serialization as a UTF-8 encoded byte string.
@@ -74,30 +68,16 @@ UTF-8 encoded byte string.
 
 use Type::Tiny;
 
-package Attean::API::Serializer 0.034 {
+package Attean::API::Serializer 0.001 {
 	use Moo::Role;
-	use Carp qw(confess);
 	
 	requires 'canonical_media_type'; # => (is => 'ro', isa => 'Str', init_arg => undef);
 	requires 'media_types'; # => (is => 'ro', isa => 'ArrayRef[Str]', init_arg => undef);
 	requires 'handled_type'; # => (is => 'ro', isa => 'Type::Tiny', init_arg => undef);
-	requires 'file_extensions'; # => (is => 'ro', isa => 'ArrayRef[Str]', init_arg => undef);
-
+	
 	requires 'serialize_iter_to_io';		# serialize_iter_to_io($io, $iter)
 	requires 'serialize_iter_to_bytes';		# $data = serialize_iter_to_bytes($iter)
 
-	before 'serialize_iter_to_io' => sub {
-		my $self	= shift;
-		my $io		= shift || confess "No filehandle passed to serialize_iter_to_io";
-		my $iter	= shift || confess "No iterator passed to serialize_iter_to_io";
-	};
-
-	before 'serialize_iter_to_bytes' => sub {
-		my $self	= shift;
-		my $iter	= shift || confess "No iterator passed to serialize_iter_to_bytes";
-	};
-
-
 	sub serialize_list_to_io {
 		my $self	= shift;
 		my $io		= shift;
@@ -110,31 +90,27 @@ package Attean::API::Serializer 0.034 {
 		my $iter	= Attean::ListIterator->new( values => [@_], item_type => $self->handled_type->role );
 		return $self->serialize_iter_to_bytes($iter);
 	}
-	
-	sub file_extensions { return [] }
 }
 
-package Attean::API::AbbreviatingSerializer 0.034 {
+package Attean::API::AbbreviatingSerializer 0.001 {
 	# Serializer that can make use of a base IRI and/or prefix IRI mappings
-	use Types::Standard qw(InstanceOf ConsumerOf Maybe Bool);
-	use Types::Namespace qw( NamespaceMap );
-
 	use Moo::Role;
+	use Types::Standard qw(InstanceOf ConsumerOf Maybe);
+	use namespace::clean;
 
 	with 'Attean::API::Serializer';
 
 	has base		=> (is => 'ro', isa => ConsumerOf['Attean::API::IRI'], predicate => 'has_base');
-	has namespaces	=> (is => 'ro', isa => Maybe[NamespaceMap], predicate => 'has_namespaces');
-	has omit_base => (is => 'ro', isa => Bool, default => 0);
+	has namespaces	=> (is => 'ro', isa => Maybe[InstanceOf['URI::NamespaceMap']], predicate => 'has_namespaces');
 }
 
-package Attean::API::AppendableSerializer 0.034 {
+package Attean::API::AppendableSerializer 0.001 {
 	# Serializer for a format that allows multiple serialization calls to be appended and remain syntactically valid
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 }
 
-package Attean::API::TermSerializer 0.034 {
+package Attean::API::TermSerializer 0.001 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	sub handled_type {
@@ -143,7 +119,7 @@ package Attean::API::TermSerializer 0.034 {
 	}
 }
 
-package Attean::API::TripleSerializer 0.034 {
+package Attean::API::TripleSerializer 0.001 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	sub handled_type {
@@ -152,7 +128,7 @@ package Attean::API::TripleSerializer 0.034 {
 	}
 }
 
-package Attean::API::QuadSerializer 0.034 {
+package Attean::API::QuadSerializer 0.001 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	
@@ -162,7 +138,7 @@ package Attean::API::QuadSerializer 0.034 {
 	}
 }
 
-package Attean::API::MixedStatementSerializer 0.034 {
+package Attean::API::MixedStatementSerializer 0.001 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	
@@ -172,37 +148,13 @@ package Attean::API::MixedStatementSerializer 0.034 {
 	}
 }
 
-package Attean::API::ResultSerializer 0.034 {
+package Attean::API::ResultSerializer 0.001 {
 	use Moo::Role;
 	with 'Attean::API::Serializer';
 	sub handled_type {
 		state $ITEM_TYPE = Type::Tiny::Role->new(role => 'Attean::API::Result');
 		return $ITEM_TYPE;
 	}
-	
-	around 'serialize_list_to_io' => sub {
-		my $orig	= shift;
-		my $self	= shift;
-		my $io		= shift;
-		my @vars;
-		if (scalar(@_)) {
-			@vars	= $_[0]->variables;
-		}
-		
-		my $iter	= Attean::ListIterator->new( values => [@_], item_type => $self->handled_type->role, variables => \@vars );
-		return $self->serialize_iter_to_io($io, $iter);
-	};
-	
-	around 'serialize_list_to_bytes' => sub {
-		my $orig	= shift;
-		my $self	= shift;
-		my @vars;
-		if (scalar(@_)) {
-			@vars	= $_[0]->variables;
-		}
-		my $iter	= Attean::ListIterator->new( values => [@_], item_type => $self->handled_type->role, variables => \@vars );
-		return $self->serialize_iter_to_bytes($iter);
-	};
 }
 
 1;
@@ -216,7 +168,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-
+L<http://www.perlrdf.org/>
 
 =head1 AUTHOR
 
@@ -224,7 +176,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams.
+Copyright (c) 2014 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
