@@ -7,7 +7,7 @@ Attean::API::Term - RDF Terms
 
 =head1 VERSION
 
-This document describes Attean::API::Term version 0.034
+This document describes Attean::API::Term version 0.001
 
 =head1 DESCRIPTION
 
@@ -39,40 +39,23 @@ This role provides default implementations of the following methods:
 
 Returns a string serialization of the term.
 
+=back
+
 =cut
 
-package Attean::API::Term 0.034 {
+package Attean::API::Term 0.001 {
 	use Moo::Role;
 	
 	with 'Attean::API::TermOrVariable', 'Attean::API::ResultOrTerm';
-	with 'Attean::API::TermOrVariableOrTriplePattern';
 	
 	requires 'value'; # => (is => 'ro', isa => 'Str', required => 1);
 	requires 'ntriples_string';
 	sub as_string {
 		shift->ntriples_string();
 	}
-
-=item C<< ebv >>
-
-Returns true if the term has a true SPARQL "effective boolean value", false otherwise.
-
-=cut
-
-	requires 'ebv';
-	requires 'compare';
-	requires 'sameTerms';
+	sub ebv { return 0; }
 	
-=item C<< order ( $other ) >>
-
-Similar to C<< compare >>, but provides the ordering semantics of ORDER BY.
-
-=cut
-
-	sub order {
-		my $self	= shift;
-		return $self->compare(@_);
-	}
+	requires 'compare';
 	
 	sub __ntriples_string {
 		my $self	= shift;
@@ -116,23 +99,16 @@ Similar to C<< compare >>, but provides the ordering semantics of ORDER BY.
 		}
 		return $string;
 	}
-
-	with 'Attean::API::TermOrTriple';
 }
 
-package Attean::API::Literal 0.034 {
+package Attean::API::Literal 0.001 {
+	use Moo::Role;
 	use IRI;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Maybe Str ConsumerOf);
-	use AtteanX::SPARQL::Constants;
-	use AtteanX::SPARQL::Token;
-	use Attean::API::Query;
-
-	use Moo::Role;
+	use namespace::clean;
 	
 	with 'Attean::API::Term';
-	with 'Attean::API::SPARQLSerializable';
-	with 'Attean::API::TermOrVariableOrTriplePattern';
 	
 	requires 'language'; # => (is => 'ro', isa => 'Maybe[Str]', predicate => 'has_language');
 	requires 'datatype'; # => (is => 'ro', isa => 'Attean::API::IRI', required => 1, coerce => 1, default => sub { IRI->new(value => 'http://www.w3.org/2001/XMLSchema#string') });
@@ -167,43 +143,13 @@ package Attean::API::Literal 0.034 {
 		if (my $dt = $self->datatype) {
 			my $type	= $dt->value;
 			if ($type =~ qr<^http://www[.]w3[.]org/2001/XMLSchema#(?:integer|decimal|float|double|non(?:Positive|Negative)Integer|(?:positive|negative)Integer|long|int|short|byte|unsigned(?:Long|Int|Short|Byte))$>) {
-				Moo::Role->apply_roles_to_object($self, 'Attean::API::NumericLiteral');
-			} elsif ($type eq 'http://www.w3.org/2001/XMLSchema#boolean') {
-				Moo::Role->apply_roles_to_object($self, 'Attean::API::BooleanLiteral');
+				Role::Tiny->apply_roles_to_object($self, 'Attean::API::NumericLiteral');
 			} elsif ($type eq 'http://www.w3.org/2001/XMLSchema#dateTime') {
-				Moo::Role->apply_roles_to_object($self, 'Attean::API::DateTimeLiteral');
-			} elsif (my $role = Attean->get_datatype_role($type)) {
-				Moo::Role->apply_roles_to_object($self, $role);
+				Role::Tiny->apply_roles_to_object($self, 'Attean::API::DateTimeLiteral');
 			}
 		}
 	};
 	
-	sub sparql_tokens {
-		my $self	= shift;
-		my @tokens;
-		
-		my $dt = $self->datatype;
-		if ($self->does('Attean::API::NumericLiteral') and $dt->value eq 'http://www.w3.org/2001/XMLSchema#integer') {
-			if ($self->value =~ /^\d+$/) {
-				my $t	= AtteanX::SPARQL::Token->fast_constructor( INTEGER, -1, -1, -1, -1, [$self->value] );
-				return Attean::ListIterator->new( values => [$t], item_type => 'AtteanX::SPARQL::Token' );
-			}
-		}
-		
-		my $t	= AtteanX::SPARQL::Token->fast_constructor( STRING1D, -1, -1, -1, -1, [$self->value] );
-		push(@tokens, $t);
-		if (my $lang = $self->language) {
-			my $l	= AtteanX::SPARQL::Token->fast_constructor( LANG, -1, -1, -1, -1, ["$lang"] );
-			push(@tokens, $l);
-		} else {
-			if ($dt->value ne 'http://www.w3.org/2001/XMLSchema#string') {
-				push(@tokens, AtteanX::SPARQL::Token->hathat);
-				push(@tokens, $dt->sparql_tokens->elements);
-			}
-		}
-		return Attean::ListIterator->new( values => \@tokens, item_type => 'AtteanX::SPARQL::Token' );
-	}
-	
 	sub ebv {
 		my $self	= shift;
 		my $value	= $self->value;
@@ -218,25 +164,11 @@ package Attean::API::Literal 0.034 {
 	sub compare {
 		my ($a, $b)	= @_;
 		return 1 unless blessed($b);
-		return 1 unless ($b->does('Attean::API::Literal') or $b->does('Attean::API::Binding'));
-		return -1 if ($b->does('Attean::API::Binding'));
+		return 1 unless ($b->does('Attean::API::Literal'));
 		my $c	= ((($a->language // '') cmp ($b->language // '')) || ($a->datatype->value cmp $b->datatype->value) || ($a->value cmp $b->value));
 		return $c;
 	}
 	
-=item C<< sameTerms( $other ) >>
-
-=cut
-
-	sub sameTerms {
-		my $lhs	= shift;
-		my $rhs	= shift;
-		return 0 unless ($rhs->does('Attean::API::Literal'));
-		return 0 unless ($lhs->value eq $rhs->value);
-		return 0 unless ($lhs->datatype->value eq $rhs->datatype->value);
-		return 1;
-	}
-	
 	if ($ENV{ATTEAN_TYPECHECK}) {
 		my %map	= (
 			language	=> Maybe[Str],
@@ -267,34 +199,6 @@ package Attean::API::Literal 0.034 {
 		return %args;
 	}
 	
-	sub argument_compatible {
-		my $self	= shift;
-		my @terms	= @_;
-		
-		if (my $l = $self->language) {
-			foreach my $t (@terms) {
-				return 0 unless ($t->does('Attean::API::Literal'));
-				if ($t->language) {
-					return 0 unless (defined($t->language));
-					return 0 unless ($t->language eq $l);
-				} else {
-					return 0 unless ($t->datatype->value eq 'http://www.w3.org/2001/XMLSchema#string');
-				}
-			}
-			return 1;
-		} elsif ($self->datatype->value eq 'http://www.w3.org/2001/XMLSchema#string') {
-			foreach my $t (@terms) {
-				return 0 unless ($t->does('Attean::API::Literal'));
-				return 0 if ($t->language);
-				return 0 unless (blessed($t->datatype));
-				return 0 unless ($t->datatype->value eq 'http://www.w3.org/2001/XMLSchema#string');
-			}
-			return 1;
-		}
-		
-		return 0;
-	}
-	
 	sub _ntriples_string {
 		my $self	= shift;
 		my $str		= sprintf('"%s"', $self->__ntriples_string);
@@ -309,25 +213,12 @@ package Attean::API::Literal 0.034 {
 			}
 		}
 	}
-
-	around as_sparql => sub {
-		my $orig	= shift;
-		my $self	= shift;
-		my $s		= $self->$orig(@_);
-		
-		if ($s =~ m[^"(true|false)"\^\^<http://www[.]w3[.]org/2001/XMLSchema#boolean>$]) {
-			return $1;
-		}
-		
-		return $s;
-	};
 }
 
-package Attean::API::DateTimeLiteral 0.034 {
-	use DateTime::Format::W3CDTF;
-
+package Attean::API::DateTimeLiteral 0.001 {
 	use Moo::Role;
-
+	use DateTime::Format::W3CDTF;
+	use namespace::clean;
 	sub datetime {
 		my $self	= shift;
 		my $w3c	= DateTime::Format::W3CDTF->new;
@@ -335,59 +226,20 @@ package Attean::API::DateTimeLiteral 0.034 {
 	}
 }
 
-package Attean::API::CanonicalizingLiteral 0.034 {
+package Attean::API::CanonicalizingLiteral 0.001 {
 	use Moo::Role;
 	requires 'canonicalized_term';
-	requires 'canonicalized_term_strict';
 }
 
-package Attean::API::BooleanLiteral 0.034 {
-	use Scalar::Util qw(blessed looks_like_number);
-
+package Attean::API::NumericLiteral 0.001 {
 	use Moo::Role;
-
-	sub canonicalized_term_strict {
-		my $self	= shift;
-		my $value	= $self->value;
-		if ($value =~ m/^(true|false|0|1)$/) {
-			return ($value eq 'true' or $value eq '1')
-				? Attean::Literal->true
-				: Attean::Literal->false;
-		} else {
-			die "Bad lexical form for xsd:boolean: '$value'";
-		}
-	}
-
-	sub canonicalized_term {
-		my $self	= shift;
-		my $value	= $self->value;
-		if ($value =~ m/^(true|false|0|1)$/) {
-			return ($value eq 'true' or $value eq '1')
-				? Attean::Literal->true
-				: Attean::Literal->false;
-		} else {
-			return $self;
-		}
-	}
-	with 'Attean::API::Literal', 'Attean::API::CanonicalizingLiteral';
-}
-
-package Attean::API::NumericLiteral 0.034 {
 	use Scalar::Util qw(blessed looks_like_number);
-
-	use Moo::Role;
-
-	sub equals {
-		my ($a, $b)	= @_;
-		return 0 unless ($b->does('Attean::API::NumericLiteral'));
-		return $a->numeric_value == $b->numeric_value;
-	}
-
+	use namespace::clean;
+	
 	sub compare {
 		my ($a, $b)	= @_;
 		return 1 unless blessed($b);
-		return 1 unless ($b->does('Attean::API::Literal') or $b->does('Attean::API::Binding'));
-		return -1 if ($b->does('Attean::API::Binding'));
+		return 1 unless ($b->does('Attean::API::Literal'));
 		if ($b->does('Attean::API::NumericLiteral')) {
 			return $a->numeric_value <=> $b->numeric_value;
 		} else {
@@ -395,20 +247,9 @@ package Attean::API::NumericLiteral 0.034 {
 # 			Attean::API::Literal::compare($a, $b);
 		}
 	}
-
-	sub canonicalized_term_strict {
-		my $self	= shift;
-		return $self->_canonicalized_term(1, @_);
-	}
 	
 	sub canonicalized_term {
 		my $self	= shift;
-		return $self->_canonicalized_term(0, @_);
-	}
-	
-	sub _canonicalized_term {
-		my $self	= shift;
-		my $strict	= shift;
 		my $value	= $self->value;
 		my $type	= $self->datatype->value;
 		$type		=~ s/^.*#//;
@@ -420,17 +261,7 @@ package Attean::API::NumericLiteral 0.034 {
 				$num		=~ s/^0+(\d)/$1/;
 				return Attean::Literal->integer("${sign}${num}");
 			} else {
- 				die "Bad lexical form for xsd:integer: '$value'" if ($strict);
-				return $self;
-			}
-		} elsif ($type eq 'negativeInteger') {
-			if ($value =~ m/^-(\d+)$/) {
-				my $num		= $1;
-				$num		=~ s/^0+(\d)/$1/;
-				return Attean::Literal->new(value => "-${num}", datatype => 'http://www.w3.org/2001/XMLSchema#negativeInteger');
-			} else {
-				die "Bad lexical form for xsd:integer: '$value'" if ($strict);
-				return $self;
+				die "Bad lexical form for xsd:integer: '$value'";
 			}
 		} elsif ($type eq 'decimal') {
 			if ($value =~ m/^([-+])?((\d+)([.]\d*)?)$/) {
@@ -440,7 +271,7 @@ package Attean::API::NumericLiteral 0.034 {
 				my $frac	= $4;
 				$sign		= '' if ($sign eq '+');
 				$num		=~ s/^0+(.)/$1/;
-				$num		=~ s/[.](\d+)0+$/.$1/;
+				$num		=~ s/[.](\d)0+$/.$1/;
 				if ($num =~ /^[.]/) {
 					$num	= "0$num";
 				}
@@ -455,8 +286,7 @@ package Attean::API::NumericLiteral 0.034 {
 				$num		=~ s/^0+(.)/$1/;
 				return Attean::Literal->decimal("${sign}${num}");
 			} else {
-				die "Bad lexical form for xsd:deciaml: '$value'" if ($strict);
-				return $self;
+				die "Bad lexical form for xsd:deciaml: '$value'";
 			}
 		} elsif ($type eq 'float') {
 			if ($value =~ m/^(?:([-+])?(?:(\d+(?:\.\d*)?|\.\d+)([Ee][-+]?\d+)?|(INF)))|(NaN)$/) {
@@ -482,17 +312,7 @@ package Attean::API::NumericLiteral 0.034 {
 				$exp	=~ s/E(-?)0+$/E${1}0/;
 				return Attean::Literal->float("${sign}${num}${exp}");
 			} else {
-				die "Bad lexical form for xsd:float: '$value'" if ($strict);
-				return $self;
-			}
-		} elsif ($type eq 'boolean') {
-			if ($value =~ m/^(true|false|0|1)$/) {
-				return ($value eq 'true' or $value eq '1')
-					? Attean::Literal->true
-					: Attean::Literal->false;
-			} else {
-				die "Bad lexical form for xsd:boolean: '$value'" if ($strict);
-				return $self;
+				die "Bad lexical form for xsd:float: '$value'";
 			}
 		} elsif ($type eq 'double') {
 			if ($value =~ m/^(?:([-+])?(?:(\d+(?:\.\d*)?|\.\d+)([Ee][-+]?\d+)?|(INF)))|(NaN)$/) {
@@ -518,11 +338,8 @@ package Attean::API::NumericLiteral 0.034 {
 				$exp	=~ s/E(-?)0+$/E${1}0/;
 				return Attean::Literal->double("${sign}${num}${exp}");
 			} else {
-				die "Bad lexical form for xsd:double: '$value'" if ($strict);
-				return $self;
+				die "Bad lexical form for xsd:double: '$value'";
 			}
-		} else {
-			warn "No canonicalization for type $type";
 		}
 		return $self;
 	}
@@ -605,112 +422,49 @@ package Attean::API::NumericLiteral 0.034 {
 	with 'Attean::API::Literal', 'Attean::API::CanonicalizingLiteral';
 }
 
-package Attean::API::Blank 0.034 {
-	use Scalar::Util qw(blessed);
-	use AtteanX::SPARQL::Constants;
-	use AtteanX::SPARQL::Token;
-	use Attean::API::Query;
-
+package Attean::API::Blank 0.001 {
 	use Moo::Role;
+	use Scalar::Util qw(blessed);
+	use namespace::clean;
 	
 	sub ebv { return 1; }
-	with 'Attean::API::Term', 'Attean::API::BlankOrIRI', 'Attean::API::BlankOrIRIOrTriple';
-;
-	with 'Attean::API::SPARQLSerializable';
-	
-	sub sparql_tokens {
-		my $self	= shift;
-		my $t	= AtteanX::SPARQL::Token->fast_constructor( BNODE, -1, -1, -1, -1, [$self->value] );
-		return Attean::ListIterator->new( values => [$t], item_type => 'AtteanX::SPARQL::Token' );
-	}
-	
+	with 'Attean::API::Term', 'Attean::API::BlankOrIRI';
+
 	sub compare {
 		my ($a, $b)	= @_;
 		return 1 unless blessed($b);
 		return -1 unless ($b->does('Attean::API::Blank'));
 		return ($a->value cmp $b->value);
 	}
-
-=item C<< sameTerms( $other ) >>
-
-=cut
-
-	sub sameTerms {
-		my $lhs	= shift;
-		my $rhs	= shift;
-		return 0 unless ($rhs->does('Attean::API::Blank'));
-		return 0 unless ($lhs->value eq $rhs->value);
-		return 1;
-	}
 }
 
-package Attean::API::IRI 0.034 {
+package Attean::API::IRI 0.001 {
+	use Moo::Role;
 	use IRI;
 	use Scalar::Util qw(blessed);
-	use AtteanX::SPARQL::Constants;
-	use AtteanX::SPARQL::Token;
-	use Attean::API::Query;
-
-	use Moo::Role;
+	use namespace::clean;
 	
 	sub ebv { return 1; }
-	with 'Attean::API::Term', 'Attean::API::BlankOrIRI', 'Attean::API::BlankOrIRIOrTriple';
-	with 'Attean::API::SPARQLSerializable';
-	
-	sub sparql_tokens {
-		my $self	= shift;
-		my @tokens;
-		if ($self->value eq '') {
-			push(@tokens, AtteanX::Parser::Turtle::Token->a);
-		} else {
-			push(@tokens, AtteanX::SPARQL::Token->fast_constructor( IRI, -1, -1, -1, -1, [$self->value] ));
-		}
-		return Attean::ListIterator->new( values => \@tokens, item_type => 'AtteanX::SPARQL::Token' );
-	}
+	with 'Attean::API::Term', 'Attean::API::BlankOrIRI';
 	
 	sub compare {
 		my ($a, $b)	= @_;
 		return 1 unless blessed($b);
-		return -1 if ($b->does('Attean::API::Literal') or $b->does('Attean::API::Binding'));
+		return -1 if ($b->does('Attean::API::Literal'));
 		return 1 unless ($b->does('Attean::API::IRI'));
 		return ($a->value cmp $b->value);
 	}
 	
-=item C<< sameTerms( $other ) >>
-
-=cut
-
-	sub sameTerms {
-		my $lhs	= shift;
-		my $rhs	= shift;
-		return 0 unless ($rhs->does('Attean::API::IRI'));
-		return 0 unless ($lhs->value eq $rhs->value);
-		return 1;
-	}
-
 	sub _ntriples_string {
 		my $self	= shift;
 		return sprintf('<%s>', $self->__ntriples_string);
 	}
-
-	around as_sparql => sub {
-		my $orig	= shift;
-		my $self	= shift;
-		
-		if ($self->value eq 'http://www.w3.org/1999/02/22-rdf-syntax-ns#type') {
-			return 'a';
-		}
-
-		return $self->$orig(@_);
-	};
 }
 
 1;
 
 __END__
 
-=back
-
 =head1 BUGS
 
 Please report any bugs or feature requests to through the GitHub web interface
@@ -718,7 +472,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-
+L<http://www.perlrdf.org/>
 
 =head1 AUTHOR
 
@@ -726,7 +480,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams.
+Copyright (c) 2014 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
