@@ -7,7 +7,7 @@ Attean::Blank - RDF blank nodes
 
 =head1 VERSION
 
-This document describes Attean::Blank version 0.027
+This document describes Attean::Blank version 0.001
 
 =head1 SYNOPSIS
 
@@ -33,10 +33,10 @@ This role consumes L<Attean::API::Blank>, which provides the following methods:
 
 =cut
 
-package Attean::Blank 0.027 {
+package Attean::Blank 0.001 {
 	use Moo;
 	use Types::Standard qw(Str);
-	use UUID::Tiny ':std';
+	use Data::UUID;
 	use namespace::clean;
 	
 	has 'value' => (is => 'ro', isa => Str, required => 1);
@@ -49,11 +49,10 @@ package Attean::Blank 0.027 {
 		my $class	= shift;
 		
 		if (scalar(@_) == 0) {
-			my $uuid	= unpack('H*', create_uuid());
-			return $class->$orig(value => 'b' . $uuid);
+			my $uuid	= Data::UUID->new->create_hex;
+			return $class->$orig(value => $uuid);
 		} elsif (scalar(@_) == 1) {
-			my $value	= shift // '';
-			return $class->$orig(value => $value);
+			return $class->$orig(value => shift);
 		}
 		return $class->$orig(@_);
 	};
@@ -75,7 +74,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-
+L<http://www.perlrdf.org/>
 
 =head1 AUTHOR
 
@@ -83,7 +82,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2020 Gregory Todd Williams.
+Copyright (c) 2014 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
