@@ -7,7 +7,7 @@ Attean::CodeIterator - Iterator implementation backed by a generator function
 
 =head1 VERSION
 
-This document describes Attean::CodeIterator version 0.030
+This document describes Attean::CodeIterator version 0.001
 
 =head1 SYNOPSIS
 
@@ -52,18 +52,16 @@ that will be returned from the iterator.
 
 =cut
 
-package Attean::CodeIterator 0.030 {
+package Attean::CodeIterator 0.001 {
 	use Moo;
 	use Type::Tiny::Role;
-	use Scalar::Util qw(blessed);
 	use Types::Standard qw(CodeRef ArrayRef);
-	use Role::Tiny ();
 	use namespace::clean;
 	
 	with 'Attean::API::Iterator';
 	
 	has generator => (is => 'ro', isa => CodeRef, required => 1);
-	has _buffer => (is => 'ro', isa => ArrayRef, init_arg => undef, default => sub { [] });
+	has buffer => (is => 'ro', isa => ArrayRef, init_arg => undef, default => sub { [] });
 
 =item C<< next >>
 
@@ -73,7 +71,7 @@ Returns the iterator's next item, or undef upon reaching the end of iteration.
 
 	sub next {
 		my $self	= shift;
-		my $buffer	= $self->_buffer;
+		my $buffer	= $self->buffer;
 		if (scalar(@$buffer)) {
 			return shift(@$buffer);
 		}
@@ -85,9 +83,7 @@ Returns the iterator's next item, or undef upon reaching the end of iteration.
 		}
 		my $role	= $self->item_type;
 		if (Role::Tiny->is_role($role)) {
-			unless (blessed($item) and $item->does($role)) {
-				die "CodeIterator item is not a $role: $item";
-			}
+			die "CodeIterator item is not a $role" unless ($item->does($role));
 		}
 		return $item;
 	}
@@ -106,7 +102,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-
+L<http://www.perlrdf.org/>
 
 =head1 AUTHOR
 
@@ -114,7 +110,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2020 Gregory Todd Williams.
+Copyright (c) 2014 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
