@@ -7,7 +7,7 @@ Attean::IRI - RDF Internationalized Resource Identifiers (IRIs)
 
 =head1 VERSION
 
-This document describes Attean::IRI version 0.034
+This document describes Attean::IRI version 0.001
 
 =head1 SYNOPSIS
 
@@ -28,35 +28,16 @@ and extends the L<IRI> class.
 
 =cut
 
-package Attean::IRI 0.034 {
+package Attean::IRI 0.001 {
 	use Moo;
 	use Types::Standard qw(Str);
-	use IRI 0.005;
+	use IRI 0.003;
 	use namespace::clean;
 
 	extends 'IRI';
 	
 	has 'ntriples_string'	=> (is => 'ro', isa => Str, lazy => 1, builder => '_ntriples_string');
 
-=item C<< equals ( $iri ) >>
-
-Returns true if C<< $iri >> is equal to the invocant, false otherwise.
-
-=cut
-
-	sub equals {
-		# This overrides the Attean::API::TermOrVariable::equals implementation
-		# to allow lazy IRIs to remain unparsed for the case where neither has
-		# a base IRI.
-		my ($a, $b)	= @_;
-		if ($b->isa('Attean::IRI')) {
-			unless ($a->has_base or $b->has_base) {
-				return ($a->value eq $b->value);
-			}
-		}
-		return ($a->as_string eq $b->as_string);
-	}
-	
 	with 'Attean::API::IRI';
 	with 'Attean::API::BlankOrIRI';
 
@@ -107,7 +88,7 @@ L<IRI>
 
 L<http://www.ietf.org/rfc/rfc3987.txt>
 
-
+L<http://www.perlrdf.org/>
 
 =head1 AUTHOR
 
@@ -115,7 +96,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams.
+Copyright (c) 2014 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
