@@ -7,7 +7,7 @@ Attean::ListIterator - Iterator implementation backed by a list/array of values
 
 =head1 VERSION
 
-This document describes Attean::ListIterator version 0.028
+This document describes Attean::ListIterator version 0.001
 
 =head1 SYNOPSIS
 
@@ -49,9 +49,8 @@ iterator.
 
 =cut
 
-package Attean::ListIterator 0.028 {
+package Attean::ListIterator 0.001 {
 	use Moo;
-	use Scalar::Util qw(blessed);
 	use Type::Tiny::Role;
 	use Types::Standard qw(ArrayRef Int);
 	use namespace::clean;
@@ -64,7 +63,7 @@ package Attean::ListIterator 0.028 {
 		my $role	= $self->item_type;
 		foreach my $item (@{ $self->values }) {
 			if (Role::Tiny->is_role($role)) {
-				die "ListIterator item <$item> is not a $role" unless (blessed($item) and $item->does($role));
+				die "ListIterator item is not a $role" unless ($item->does($role));
 			}
 		}
 	}
@@ -97,18 +96,6 @@ Returns the iterator's next item, or undef upon reaching the end of iteration.
 		return $item;
 	}
 
-=item C<< size >>
-
-Returns the number of elements still remaining in the iterator until it is
-fully consumed or until C<< reset >> is called.
-
-=cut
-
-	sub size {
-		my $self	= shift;
-		return scalar(@{ $self->values }) - $self->current;
-	}
-	
 	with 'Attean::API::RepeatableIterator';
 }
 
@@ -125,7 +112,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-
+L<http://www.perlrdf.org/>
 
 =head1 AUTHOR
 
@@ -133,7 +120,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2020 Gregory Todd Williams.
+Copyright (c) 2014 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
