@@ -7,7 +7,7 @@ Attean::Literal - RDF Literals
 
 =head1 VERSION
 
-This document describes Attean::Literal version 0.034
+This document describes Attean::Literal version 0.001
 
 =head1 SYNOPSIS
 
@@ -24,37 +24,15 @@ This document describes Attean::Literal version 0.034
 The Attean::Literal class represents RDF literals.
 It conforms to the L<Attean::API::Literal|Attean::API::Term> role.
 
-=head1 ATTRIBUTES
-
-The following attributes exist:
-
-=over 4
-
-=item C<< value >>
-
-=item C<< language >>
-
-=item C<< datatype >>
-
-=back
-
-=head1 METHODS
-
-=over 4
-
-=item C<< has_language >>
-
-Returns true if the literal has a language tag, false otherwise.
-
 =cut
 
-package Attean::Literal 0.034 {
+package Attean::Literal 0.001 {
 	use Moo;
 	use Types::Standard qw(Str Maybe InstanceOf);
 	use Attean::API::Term;
 	use IRI;
 	use Sub::Install;
-	use Sub::Util qw(set_subname);
+	use Sub::Name;
 	use Scalar::Util qw(blessed);
 	use namespace::clean;
 	
@@ -65,14 +43,7 @@ package Attean::Literal 0.034 {
 		is => 'ro',
 		isa => InstanceOf['Attean::IRI'],
 		required => 1,
-		coerce => sub {
-			my $dt	= shift;
-			if (blessed($dt) and $dt->isa('Attean::IRI')) {
-				return $dt;
-			} else {
-				return blessed($dt) ? Attean::IRI->new($dt->as_string) : Attean::IRI->new($dt)
-			}
-		},
+		coerce => sub { blessed($_[0]) ? Attean::IRI->new($_[0]->as_string) : Attean::IRI->new($_[0]) },
 		default => sub { $XSD_STRING }
 	);
 	has 'ntriples_string'	=> (is => 'ro', isa => Str, lazy => 1, builder => '_ntriples_string');
@@ -90,11 +61,16 @@ package Attean::Literal 0.034 {
 		return $class->$orig(@_);
 	};
 	
+	sub BUILD {
+		my $self	= shift;
+		die unless ($self->has_language or length($self->datatype->as_string));
+	}
+	
 	around 'datatype'	=> sub {
 		my $orig	= shift;
 		my $self	= shift;
 		if ($self->has_language) {
-			return Attean::IRI->new(value => 'http://www.w3.org/1999/02/22-rdf-syntax-ns#langString');
+			return Attean::IRI->new(value => 'http://www.w3.org/2001/XMLSchema#string');
 		} else {
 			return $self->$orig(@_);
 		}
@@ -119,23 +95,11 @@ package Attean::Literal 0.034 {
 		}
 	}
 
-=item C<< true >>
-
-The xsd:true term.
-
-=cut
-
 	sub true {
 		state $v	= Attean::Literal->new( value => 'true', datatype => 'http://www.w3.org/2001/XMLSchema#boolean' );
 		return $v;
 	}
 	
-=item C<< false >>
-
-The xsd:false term.
-
-=cut
-
 	sub false {
 		state $v	= Attean::Literal->new( value => 'false', datatype => 'http://www.w3.org/2001/XMLSchema#boolean' );
 		return $v;
@@ -148,7 +112,7 @@ The xsd:false term.
 				return $class->new( value => shift, datatype => "http://www.w3.org/2001/XMLSchema#$method" );
 			};
 			Sub::Install::install_sub({
-				code	=> set_subname("${method}", $code),
+				code	=> subname("${method}", $code),
 				as		=> "${method}"
 			});
 		}
@@ -160,8 +124,6 @@ The xsd:false term.
 
 __END__
 
-=back
-
 =head1 BUGS
 
 Please report any bugs or feature requests to through the GitHub web interface
@@ -169,7 +131,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-
+L<http://www.perlrdf.org/>
 
 =head1 AUTHOR
 
@@ -177,7 +139,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams.
+Copyright (c) 2014 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
