@@ -7,7 +7,7 @@ Attean::Quad - RDF Quads
 
 =head1 VERSION
 
-This document describes Attean::Quad version 0.026
+This document describes Attean::Quad version 0.001
 
 =head1 SYNOPSIS
 
@@ -22,7 +22,7 @@ It conforms to the L<Attean::API::Quad|Attean::API::Binding> role.
 
 =head1 ROLES
 
-This class consumes L<Attean::API::Quad>.
+This role consumes L<Attean::API::Quad>.
 
 =head1 METHODS
 
@@ -40,11 +40,9 @@ This class consumes L<Attean::API::Quad>.
 
 =cut
 
-package Attean::QuadPattern 0.026 {
+package Attean::QuadPattern 0.001 {
 	use Moo;
-	use Scalar::Util qw(blessed);
-	use Attean::RDF;
-	use Attean::API::Binding;
+	use Attean::API;
 	
 	has 'subject'	=> (is => 'ro', required => 1);
 	has 'predicate'	=> (is => 'ro', required => 1);
@@ -52,9 +50,20 @@ package Attean::QuadPattern 0.026 {
 	has 'graph'		=> (is => 'ro', required => 1);
 	
 	with 'Attean::API::QuadPattern';
+
+	around BUILDARGS => sub {
+		my $orig 	= shift;
+		my $class	= shift;
+		if (scalar(@_) == 4) {
+			my %args;
+			@args{ $class->variables }	= @_;
+			return $class->$orig(%args);
+		}
+		return $class->$orig(@_);
+	};
 }
 
-package Attean::Quad 0.026 {
+package Attean::Quad 0.001 {
 	use Moo;
 	use Attean::API::Binding;
 	
@@ -88,7 +97,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-
+L<http://www.perlrdf.org/>
 
 =head1 AUTHOR
 
@@ -96,7 +105,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2020 Gregory Todd Williams.
+Copyright (c) 2014 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
