@@ -7,7 +7,7 @@ Attean::QuadModel - RDF model backed by a quad-store
 
 =head1 VERSION
 
-This document describes Attean::QuadModel version 0.034
+This document describes Attean::QuadModel version 0.001
 
 =head1 SYNOPSIS
 
@@ -38,7 +38,7 @@ quad-store.
 
 =cut
 
-package Attean::QuadModel 0.034 {
+package Attean::QuadModel 0.001 {
 	use Moo;
 	use Scalar::Util qw(reftype);
 	use namespace::clean;
@@ -47,7 +47,7 @@ package Attean::QuadModel 0.034 {
 		is => 'ro',
 		does => 'Attean::API::QuadStore',
 		required => 1,
-		handles	=> [qw(size count_quads count_quads_estimate get_graphs holds)],
+		handles	=> [qw(size count_quads get_graphs)],
 	);
 	
 =item C<< get_quads ( $subject, $predicate, $object, $graph ) >>
@@ -83,50 +83,18 @@ L<Attean::API::QuadIterator>.
 				}
 			}
 		}
-		
-		if (scalar(@iters) == 0) {
-			return Attean::ListIterator->new(values => [], item_type => 'Attean::API::Quad');
-		} elsif (scalar(@iters) == 1) {
+		if (scalar(@iters) <= 1) {
 			return shift(@iters);
 		} else {
 			return Attean::IteratorSequence->new( iterators => \@iters, item_type => $iters[0]->item_type );
 		}
 	}
 	
-=item C<< plans_for_algebra( $algebra, $model, $active_graphs, $default_graphs ) >>
-
-Delegates to the underlying store if the store consumes Attean::API::CostPlanner.
-
-=cut
-
-	sub plans_for_algebra {
-		my $self	= shift;
-		if ($self->store->does('Attean::API::CostPlanner')) {
-			return $self->store->plans_for_algebra(@_);
-		}
-		return;
-	}
-	
-=item C<< cost_for_plan( $plan ) >>
-
-Delegates to the underlying store if the store consumes Attean::API::CostPlanner.
-
-=cut
-
-	sub cost_for_plan {
-		my $self	= shift;
-		if ($self->store->does('Attean::API::CostPlanner')) {
-			return $self->store->cost_for_plan(@_);
-		}
-		return;
-	}
-	
 	with 'Attean::API::Model';
-	with 'Attean::API::CostPlanner';
 }
 
 
-package Attean::MutableQuadModel 0.034 {
+package Attean::MutableQuadModel 0.001 {
 	use Moo;
 	extends 'Attean::QuadModel';
 	
@@ -134,7 +102,7 @@ package Attean::MutableQuadModel 0.034 {
 		is => 'ro',
 		does => 'Attean::API::MutableQuadStore',
 		required => 1,
-		handles	=> [qw(size count_quads count_quads_estimate add_quad remove_quad get_graphs create_graph drop_graph clear_graph add_iter)],
+		handles	=> [qw(size count_quads add_quad remove_quad get_graphs create_graph drop_graph clear_graph add_iter)],
 	);
 
 	with 'Attean::API::MutableModel';
@@ -153,7 +121,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-
+L<http://www.perlrdf.org/>
 
 =head1 AUTHOR
 
@@ -161,7 +129,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams.
+Copyright (c) 2014 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
