@@ -4,7 +4,7 @@ Attean::RDF - Utility package for exporting shorthand functions for constructing
 
 =head1 VERSION
 
-This document describes Attean::RDF version 0.034
+This document describes Attean::RDF version 0.001
 
 =head1 SYNOPSIS
 
@@ -31,18 +31,18 @@ by default).
 
 =cut
 
-package Attean::RDF 0.034 {
+package Attean::RDF 0.001 {
 	use v5.14;
 	use warnings;
 
-	require Exporter::Tiny;
-	our @ISA	= qw(Exporter::Tiny);
-	our @EXPORT	= qw(iri blank literal dtliteral langliteral variable triple quad triplepattern quadpattern bgp);
-
-	require Attean;
-	use List::Util qw(mesh);
+	use Attean;
+	use List::MoreUtils qw(zip);
+	require Exporter;
 	use namespace::clean;
 
+	our @ISA	= qw(Exporter);
+	our @EXPORT	= qw(iri blank literal dtliteral langliteral variable triple quad triplepattern);
+
 =item C<< variable( $value ) >>
 
 C<< Attean::Variable->new($value) >>
@@ -91,7 +91,7 @@ C<< Attean::Literal->new( value => $value, datatype => $dt ) >>
 
 	sub dtliteral {
 		my @k	= qw(value datatype);
-		return Attean::Literal->new(mesh \@k, \@_);
+		return Attean::Literal->new(zip @k, @_);
 	}
 
 =item C<< langliteral( $value, $lang ) >>
@@ -102,8 +102,7 @@ C<< Attean::Literal->new( value => $value, language => $lang ) >>
 
 	sub langliteral {
 		my @k	= qw(value language);
-		$DB::single = 1;
-		return Attean::Literal->new(mesh \@k, \@_);
+		return Attean::Literal->new(zip @k, @_);
 	}
 	
 =item C<< triple( @terms ) >>
@@ -135,28 +134,8 @@ C<< Attean::Quad->new( @terms ) >>
 	sub quad {
 		return Attean::Quad->new(@_);
 	}
-
-=item C<< quadpattern( @terms ) >>
-
-C<< Attean::QuadPattern->new( @terms ) >>
-
-=cut
-
-	sub quadpattern {
-		return Attean::QuadPattern->new(@_);
-	}
-
-=item C<< bgp( @triplepatterns ) >>
-
-C<< Attean::Algebra::BGP->new( triples => \@triplepatterns ) >>
-
-=cut
-
-	sub bgp {
-	  return Attean::Algebra::BGP->new(triples => \@_);
-	}
 }
-	
+
 1;
 
 __END__
@@ -174,7 +153,7 @@ L<IRI>
 
 L<http://www.ietf.org/rfc/rfc3987.txt>
 
-
+L<http://www.perlrdf.org/>
 
 =head1 AUTHOR
 
@@ -182,7 +161,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams.
+Copyright (c) 2014 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
