@@ -7,14 +7,14 @@ Attean::Result - SPARQL Result
 
 =head1 VERSION
 
-This document describes Attean::Result version 0.030
+This document describes Attean::Result version 0.001
 
 =head1 SYNOPSIS
 
   use v5.14;
   use Attean;
-  my $result = Attean::Result->new(bindings => { name => $literal, homepage => $iri } );
-  my @vars = $result->variables; # ('name', 'homepage')
+  my $result = Attean::Result->new( { name => $literal, homepage => $iri } );
+  my @vars = $result->variables; # ('name', 'iri')
   my $term = $result->value('name'); # $term == $literal
 
 =head1 DESCRIPTION
@@ -29,7 +29,7 @@ It conforms to the L<Attean::API::Result|Attean::API::Binding> role.
 
 =cut
 
-package Attean::Result 0.030 {
+package Attean::Result 0.001 {
 	use Moo;
 	use Types::Standard qw(HashRef ConsumerOf);
 	use Attean::API::Binding;
@@ -43,18 +43,7 @@ Returns the HASH reference containing the variable bindings for this result.
 
 =cut
 
-	has 'bindings' => (is => 'ro', isa => HashRef[ConsumerOf['Attean::API::TermOrTriple']], default => sub { +{} });
-
-# 	sub BUILD {
-# 		my $self	= shift;
-# 		my $args	= shift;
-# 		use Data::Dumper;
-# 		my $b		= $args->{bindings};
-# 		my $keys	= [keys %$b];
-# 		if (scalar(@$keys) == 2) {
-# 			Carp::cluck 'NEW RESULT CONSTRUCTED with variables ' . Dumper($keys);
-# 		}
-# 	}
+	has 'bindings' => (is => 'ro', isa => HashRef[ConsumerOf['Attean::API::Term']], default => sub { +{} });
 	
 =item C<< value( $name ) >>
 
@@ -62,13 +51,12 @@ Returns the term object bound to the C<< $name >>d variable, or undef if the
 name does not map to a term.
 
 =cut
-
 	sub value {
 		my $self	= shift;
 		my $k		= shift;
 		return $self->bindings->{$k};
 	}
-
+	
 =item C<< variables >>
 
 Returns a list of the variable names that are bound to terms in this result
@@ -80,7 +68,7 @@ object.
 		my $self	= shift;
 		return keys %{ $self->bindings };
 	}
-
+	
 =item C<< as_string >>
 
 Returns a string serialization of the variable bindings contained in the result.
@@ -108,7 +96,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-
+L<http://www.perlrdf.org/>
 
 =head1 AUTHOR
 
@@ -116,7 +104,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2020 Gregory Todd Williams.
+Copyright (c) 2014 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
