@@ -7,7 +7,7 @@ Attean::TermMap - Mapping terms to new terms
 
 =head1 VERSION
 
-This document describes Attean::TermMap version 0.034
+This document describes Attean::TermMap version 0.001
 
 =head1 SYNOPSIS
 
@@ -25,28 +25,17 @@ skolemize nodes, or map the nodes in some other, custom way.
 
 It conforms to the L<Attean::API::Mapper> role.
 
-=head1 ATTRIBUTES
-
-=over 4
-
-=item C<< mapper >>
-
-A CODE reference that will map L<Attean::API::Term> objects to (possibly different)
-term objects.
-
-=back
-
 =head1 CLASS METHODS
 
 =over 4
 
 =cut
 
-package Attean::TermMap 0.034 {
+package Attean::TermMap 0.001 {
 	use Moo;
 	use Types::Standard qw(CodeRef);
 	use Attean::API::Binding;
-	use UUID::Tiny ':std';
+	use Data::UUID;
 	use namespace::clean;
 	
 	with 'Attean::Mapper';
@@ -60,7 +49,7 @@ package Attean::TermMap 0.034 {
 		}
 		return $class->$orig(@_);
 	};
-
+	
 =item C<< canonicalization_map >>
 
 Returns a new L<Attean::TermMap> that canonicalizes recognized typed
@@ -73,17 +62,16 @@ L<Attean::API::Literal> values.
 		my %map;
 		return $class->new(mapper => sub {
 			my $term	= shift;
-			return $term unless ($term->does('Attean::API::Literal'));
+			return $term unless ($term->does('Attean::API::Literal') and $term->datatype);
 			
-			if ($term->does('Attean::API::CanonicalizingLiteral')) {
-				my $c	= eval { $term->canonicalized_term };
-				return ($@) ? undef : $c;
+			if ($term->does('Attean::API::NumericLiteral')) {
+				return $term->canonicalized_term;
 			}
 			
 			return $term;
 		});
 	}
-
+	
 =item C<< uuid_blank_map >>
 
 Returns a new L<Attean::TermMap> that renames blank nodes with UUID values.
@@ -99,13 +87,13 @@ Returns a new L<Attean::TermMap> that renames blank nodes with UUID values.
 			my $id		= $term->value;
 			return $map{$id} if (defined($map{$id}));
 			
-			my $uuid	= unpack('H*', create_uuid());
-			my $new		= Attean::Blank->new( 'b' . $uuid );
+			my $uuid	= Data::UUID->new->create_hex;
+			my $new		= Attean::Blank->new( $uuid );
 			$map{$id}	= $new;
 			return $new;
 		});
 	}
-
+	
 =item C<< short_blank_map >>
 
 Returns a new L<Attean::TermMap> that renames blank nodes with short
@@ -131,14 +119,6 @@ alphabetic names (e.g. _:a, _:b).
 		});
 	}
 
-=item C<< rewrite_map( \%map ) >>
-
-Given C<< %map >> whose keys are term C<< as_string >> serializations, and
-objects are L<Attean::API::Term> objects, returns a new term map object that
-maps terms matching entries in C<< %map >>, and all other terms to themselves.
-
-=cut
-
 	sub rewrite_map {
 		my $class	= shift;
 		my $map		= shift;
@@ -154,7 +134,7 @@ maps terms matching entries in C<< %map >>, and all other terms to themselves.
 =head1 METHODS
 
 =over 4
-
+	
 =item C<< map( $term ) >>
 
 Returns the term that is mapped to by the supplied C<< $term >>.
@@ -166,7 +146,7 @@ Returns the term that is mapped to by the supplied C<< $term >>.
 		my $term	= shift;
 		return $self->mapper->( $term );
 	}
-
+	
 =item C<< binding_mapper >>
 
 Returns a mapping function reference that maps L<Attean::API::Binding>
@@ -196,7 +176,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-
+L<http://www.perlrdf.org/>
 
 =head1 AUTHOR
 
@@ -204,7 +184,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams.
+Copyright (c) 2014 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
