@@ -7,7 +7,7 @@ Attean::Triple - RDF Triples
 
 =head1 VERSION
 
-This document describes Attean::Triple version 0.032
+This document describes Attean::Triple version 0.001
 
 =head1 SYNOPSIS
 
@@ -38,10 +38,8 @@ This role consumes L<Attean::API::Triple>.
 
 =cut
 
-package Attean::TriplePattern 0.032 {
+package Attean::TriplePattern 0.001 {
 	use Moo;
-	use Scalar::Util qw(blessed);
-	use Attean::RDF;
 	use Attean::API::Binding;
 	
 	has 'subject'	=> (is => 'ro', required => 1);
@@ -50,20 +48,19 @@ package Attean::TriplePattern 0.032 {
 	
 	with 'Attean::API::TriplePattern';
 	
-	sub as_quadpattern {
-		my $self	= shift;
-		my $graph	= shift;
-		# TODO: deprecate this in favor of as_quad_pattern() provided by Attean::API::TriplePattern
-		return $self->as_quad_pattern($graph);
-	}
-	
-	sub ntriples_string {
-		my $self	= shift;
-		return join(' ', '<<', (map { $self->$_()->ntriples_string() } qw(subject predicate object)), '>>');
-	}
+	around BUILDARGS => sub {
+		my $orig 	= shift;
+		my $class	= shift;
+		if (scalar(@_) == 3) {
+			my %args;
+			@args{ $class->variables }	= @_;
+			return $class->$orig(%args);
+		}
+		return $class->$orig(@_);
+	};
 }
 
-package Attean::Triple 0.032 {
+package Attean::Triple 0.001 {
 	use Moo;
 	use Attean::API::Binding;
 	
@@ -97,7 +94,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-
+L<http://www.perlrdf.org/>
 
 =head1 AUTHOR
 
@@ -105,7 +102,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams.
+Copyright (c) 2014 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
