@@ -7,7 +7,7 @@ Attean::Variable - Pattern matching variables
 
 =head1 VERSION
 
-This document describes Attean::Variable version 0.034
+This document describes Attean::Variable version 0.001
 
 =head1 SYNOPSIS
 
@@ -21,37 +21,25 @@ This document describes Attean::Variable version 0.034
 The Attean::Variable class represents variables for use in pattern matching.
 It conforms to the L<Attean::API::TermOrVariable|Attean::API> role.
 
-=head1 ATTRIBUTES
-
-=over 4
-
-=item C<< value >>
-
-=item C<< ntriples_string >>
-
-=back
-
 =cut
 
-package Attean::Variable 0.034 {
+package Attean::Variable 0.001 {
 	use Moo;
 	use Types::Standard qw(Str);
-	use UUID::Tiny ':std';
+	use Data::UUID;
 	use namespace::clean;
 	
 	has 'value' => (is => 'ro', isa => Str, required => 1);
 	has 'ntriples_string'	=> (is => 'ro', isa => Str, lazy => 1, builder => '_ntriples_string');
 
-	with 'Attean::API::Variable';
-	with 'Attean::API::TermOrVariable';
-	with 'Attean::API::TermOrVariableOrTriplePattern';
+	with 'Attean::API::Variable', 'Attean::API::TermOrVariable';
 	
 	around BUILDARGS => sub {
 		my $orig 	= shift;
 		my $class	= shift;
 		if (scalar(@_) == 0) {
-			my $uuid	= unpack('H*', create_uuid());
-			return $class->$orig(value => 'v' . $uuid);
+			my $uuid	= Data::UUID->new->create_hex;
+			return $class->$orig(value => $uuid);
 		} elsif (scalar(@_) == 1) {
 			return $class->$orig(value => shift);
 		}
@@ -75,7 +63,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-
+L<http://www.perlrdf.org/>
 
 =head1 AUTHOR
 
@@ -83,7 +71,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams.
+Copyright (c) 2014 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
