@@ -7,48 +7,25 @@ AtteanX::Parser::NQuads - N-Quads Parser
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::NQuads version 0.033
+This document describes AtteanX::Parser::NQuads version 0.001
 
 =head1 SYNOPSIS
 
  use Attean;
  my $parser = Attean->get_parser('NQuads')->new();
-
- # Parse data from a file-handle and handle quads in the 'handler' callback
  $parser->parse_cb_from_io( $fh );
- 
- # Parse the given byte-string, and return an iterator of quads
- my $iter = $parser->parse_iter_from_bytes('<http://example.org/subject> <tag:example.org:predicate> "object" <http://example.org/graph> .');
- while (my $quad = $iter->next) {
-   print $quad->as_string;
- }
 
 =head1 DESCRIPTION
 
-This module implements a parser for the N-Quads format.
-
-=head1 ROLES
-
-This class consumes L<Attean::API::Parser>, L<Attean::API::PullParser>
-and <Attean::API::MixedStatementParser>.
+...
 
 =head1 METHODS
 
 =over 4
 
-=item C<< parse_iter_from_io( $fh ) >>
-
-Returns an L<Attean::API::Iterator> that result from parsing the data read from
-the L<IO::Handle> object C<< $fh >>.
-
-=item C<< parse_iter_from_bytes( $data ) >>
-
-Returns an L<Attean::API::Iterator> that result from parsing the data read from
-the UTF-8 encoded byte string C<< $data >>.
-
 =cut
 
-package AtteanX::Parser::NQuads 0.033 {
+package AtteanX::Parser::NQuads 0.001 {
 	use utf8;
 	
 	use Attean;
@@ -84,7 +61,6 @@ Returns a list of file extensions that may be parsed with the parser.
 	
 	with 'Attean::API::MixedStatementParser';
 	with 'Attean::API::PullParser';
-	with 'Attean::API::CDTBlankNodeMappingParser';
 
 	sub _binding {
 		my $self	= shift;
@@ -117,7 +93,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
