@@ -4,51 +4,28 @@ AtteanX::Parser::NTriples - N-Triples Parser
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::NTriples version 0.033
+This document describes AtteanX::Parser::NTriples version 0.001
 
 =head1 SYNOPSIS
 
  use Attean;
  my $parser = Attean->get_parser('NTriples')->new();
-
- # Parse data from a file-handle and handle triples in the 'handler' callback
  $parser->parse_cb_from_io( $fh );
- 
- # Parse the given byte-string, and return an iterator of triples
- my $iter = $parser->parse_iter_from_bytes('<http://example.org/subject> <tag:example.org:predicate> "object" .');
- while (my $triple = $iter->next) {
-   print $triple->as_string;
- }
 
 =head1 DESCRIPTION
 
-This module implements a parser for the N-Triples format.
-
-=head1 ROLES
-
-This class consumes L<Attean::API::Parser>, L<Attean::API::PullParser>
-and <Attean::API::TripleParser>.
+...
 
 =head1 METHODS
 
 =over 4
 
-=item C<< parse_iter_from_io( $fh ) >>
-
-Returns an L<Attean::API::Iterator> that result from parsing the data read from
-the L<IO::Handle> object C<< $fh >>.
-
-=item C<< parse_iter_from_bytes( $data ) >>
-
-Returns an L<Attean::API::Iterator> that result from parsing the data read from
-the UTF-8 encoded byte string C<< $data >>.
-
 =cut
 
 use v5.14;
 use warnings;
 
-package AtteanX::Parser::NTriples 0.033 {
+package AtteanX::Parser::NTriples 0.001 {
 	use utf8;
 	
 	use Attean;
@@ -85,7 +62,6 @@ Returns a list of file extensions that may be parsed with the parser.
 	with 'Attean::API::TripleParser';
 	with 'Attean::API::PullParser';
 	with 'Attean::API::Parser';
-	with 'Attean::API::CDTBlankNodeMappingParser';
 
 	sub _binding {
 		my $self	= shift;
@@ -117,7 +93,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
