@@ -7,7 +7,7 @@ AtteanX::Parser::NTuples - Shared functionality for N-Triples and N-Quads parser
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::NTuples version 0.034
+This document describes AtteanX::Parser::NTuples version 0.001
 
 =head1 SYNOPSIS
 
@@ -15,17 +15,7 @@ This document describes AtteanX::Parser::NTuples version 0.034
 
 =head1 DESCRIPTION
 
-This module provides a base class for RDF formats N-Triples and N-Quads.
-
-=head1 ATTRIBUTES
-
-=over 4
-
-=item C<< blank_nodes >>
-
-=item C<< has_blank_nodes_map >>
-
-=back
+...
 
 =head1 METHODS
 
@@ -33,28 +23,15 @@ This module provides a base class for RDF formats N-Triples and N-Quads.
 
 =cut
 
-package AtteanX::Parser::NTuples 0.034 {
+package AtteanX::Parser::NTuples 0.001 {
 	use utf8;
 	use Moo;
 	use Attean;
-	use Carp qw(carp);
 	use Encode qw(decode);
-	use Types::Standard qw(Bool HashRef ArrayRef HashRef Str Maybe InstanceOf ConsumerOf);
 	use namespace::clean;
-
-	has 'blank_nodes'	=> (is => 'ro', isa => HashRef[ConsumerOf['Attean::API::Blank']], predicate => 'has_blank_nodes_map', default => sub { +{} });
-
-=item C<< parse_term_from_bytes( $bytes ) >>
-
-Parses the given C<< $bytes >> and returns a corresponding L<Attean::API::Term> object.
-
-=cut
-
-	sub parse_term_from_bytes {
+	
+	sub parse_term_from_string {
 		my $self	= shift;
-		unless (ref($self)) {
-			$self	= $self->new();
-		}
 		my $string	= shift;
 		my $n = $self->_eat_node( 0, $string );
 		return $n;
@@ -145,16 +122,14 @@ the data read from the L<IO::Handle> object C<< $fh >>.
 					# clear out the cache roughly every 50 IRIs
 					%cache	= ();
 				}
-				my $iri	= $self->new_iri( value => _unescape($uri, $lineno) );
+				my $iri	= Attean::IRI->new( _unescape($uri, $lineno) );
 				$cache{$uri}	= $iri;
 				return $iri;
 			}
 		} elsif ($char eq '_') {
 			my ($name)	= $_[0] =~ m/^_:([A-Za-z][A-Za-z0-9]*)/;
 			substr($_[0], 0, length($name)+2)	= '';
-			my $b	= Attean::Blank->new($name);
-			$self->blank_nodes->{$name}	= $b;
-			return $b;
+			return Attean::Blank->new( $name );
 		} elsif ($char eq '"') {
 			substr($_[0], 0, 1)	= '';
 			my $value	= decode('utf8', '');
@@ -208,13 +183,11 @@ the data read from the L<IO::Handle> object C<< $fh >>.
 				substr($_[0],0,3)	= '';
 				my ($uri)	= $_[0] =~ m/^([^>]*)>/;
 				substr($_[0], 0, length($uri)+1)	= '';
-				my $dt	= $self->new_iri(value => $uri);
-				return Attean::Literal->new( value => $value, datatype => $dt);
+				return Attean::Literal->new( value => $value, datatype => $uri);
 			} else {
 				return Attean::Literal->new($value);
 			}
 		} else {
-			Carp::cluck;
 			die qq[Not valid N-Triples node start character '$char' at line $lineno, near "$_[0]"];
 		}
 	}
@@ -292,7 +265,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
