@@ -4,7 +4,7 @@ AtteanX::Parser::SPARQLJSON - SPARQL JSON Parser
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::SPARQLJSON version 0.030
+This document describes AtteanX::Parser::SPARQLJSON version 0.001
 
 =head1 SYNOPSIS
 
@@ -16,18 +16,6 @@ This document describes AtteanX::Parser::SPARQLJSON version 0.030
 
 ...
 
-=head1 ATTRIBUTES
-
-=over 4
-
-=item C<< canonical_media_type >>
-
-=item C<< media_types >>
-
-=item C<< file_extensions >>
-
-=back
-
 =head1 METHODS
 
 =over 4
@@ -37,28 +25,42 @@ This document describes AtteanX::Parser::SPARQLJSON version 0.030
 use v5.14;
 use warnings;
 
-package AtteanX::Parser::SPARQLJSON 0.030 {
+package AtteanX::Parser::SPARQLJSON 0.001 {
 	use Attean;
 	use Moo;
 	use JSON;
 	use Encode qw(decode);
 	
+=item C<< canonical_media_type >>
+
+Returns the canonical media type for SPARQL XML: application/sparql-results+json.
+
+=cut
+
 	sub canonical_media_type { return "application/sparql-results+json" }
 
+=item C<< media_types >>
+
+Returns a list of media types that may be parsed with the SPARQL XML parser:
+application/sparql-results+json.
+
+=cut
+
 	sub media_types {
 		return [qw(application/sparql-results+json)];
 	}
 	
+=item C<< file_extensions >>
+
+Returns a list of file extensions that may be parsed with the parser.
+
+=cut
+
 	sub file_extensions { return [qw(srj)] }
 
 	with 'Attean::API::ResultOrTermParser';
-	with 'Attean::API::Parser';
 	with 'Attean::API::AtOnceParser';
 
-=item C<< parse_list_from_io( $fh ) >>
-
-=cut
-
 	sub parse_list_from_io {
 		my $self	= shift;
 		my $io		= shift;
@@ -66,10 +68,6 @@ package AtteanX::Parser::SPARQLJSON 0.030 {
 		return $self->parse_list_from_bytes($data);
 	}
 	
-=item C<< parse_list_from_bytes( $bytes ) >>
-
-=cut
-
 	sub parse_list_from_bytes {
 		my $self	= shift;
 		my $octets	= shift;
@@ -86,7 +84,28 @@ package AtteanX::Parser::SPARQLJSON 0.030 {
 				my %data;
 				foreach my $v (@$vars) {
 					if (defined(my $value = $b->{ $v })) {
-						$data{ $v }	= $self->decode_node($value);
+						my $type	= $value->{type};
+						if ($type eq 'uri') {
+							my $data	= $value->{value};
+							$data{ $v }	= Attean::IRI->new( $data );
+						} elsif ($type eq 'bnode') {
+							my $data	= $value->{value};
+							$data{ $v }	= Attean::Blank->new( $data );
+						} elsif ($type eq 'literal') {
+							my $data	= $value->{value};
+							if (my $lang = $value->{'xml:lang'}) {
+								$data{ $v }	= Attean::Literal->new( value => $data, language => $lang );
+							} else {
+								$data{ $v }	= Attean::Literal->new( $data );
+							}
+						} elsif ($type eq 'typed-literal') {
+							my $data	= $value->{value};
+							my $dt		= $value->{datatype};
+							$data{ $v }	= Attean::Literal->new( value => $data, datatype => $dt );
+						} else {
+							warn Dumper($data, $b);
+							die "Unknown node type $type during parsing of SPARQL JSON Results";
+						}
 					}
 				}
 				push(@results, Attean::Result->new( bindings => \%data ));
@@ -94,45 +113,6 @@ package AtteanX::Parser::SPARQLJSON 0.030 {
 			return @results;
 		}
 	}
-	
-=item C<< decode_node( \%value ) >>
-
-=cut
-
-	sub decode_node {
-		my $self	= shift;
-		my $value	= shift;
-		my $type	= $value->{type};
-		if ($type eq 'uri') {
-			my $data	= $value->{value};
-			return $self->new_iri( value => $data );
-		} elsif ($type eq 'bnode') {
-			my $data	= $value->{value};
-			return Attean::Blank->new( $data );
-		} elsif ($type eq 'literal') {
-			my $data	= $value->{value};
-			if (my $lang = $value->{'xml:lang'}) {
-				return Attean::Literal->new( value => $data, language => $lang );
-			} elsif (my $dt = $value->{'datatype'}) {
-				my $iri		= $self->new_iri(value => $dt);
-				return Attean::Literal->new( value => $data, datatype => $iri );
-			} else {
-				return Attean::Literal->new( $data );
-			}
-		} elsif ($type eq 'typed-literal') {
-			my $data	= $value->{value};
-			my $dt		= $value->{datatype};
-			my $iri		= $self->new_iri(value => $dt);
-			return Attean::Literal->new( value => $data, datatype => $iri );
-		} elsif ($type eq 'triple') {
-			my $s		= $self->decode_node($value->{value}{subject});
-			my $p		= $self->decode_node($value->{value}{predicate});
-			my $o		= $self->decode_node($value->{value}{object});
-			return Attean::Triple->new( $s, $p, $o );
-		} else {
-			die "Unknown node type $type during parsing of SPARQL JSON Results";
-		}
-	}
 
 }
 
@@ -154,7 +134,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2020 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
