@@ -7,7 +7,7 @@ AtteanX::Parser::SPARQLTSV - SPARQL Results TSV Parser
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::SPARQLTSV version 0.034
+This document describes AtteanX::Parser::SPARQLTSV version 0.001
 
 =head1 SYNOPSIS
 
@@ -17,30 +17,18 @@ This document describes AtteanX::Parser::SPARQLTSV version 0.034
 
 ...
 
-=head1 ATTRIBUTES
-
-=over 4
-
-=item C<< canonical_media_type >>
-
-=item C<< media_types >>
-
-=item C<< file_extensions >>
-
-=back
-
 =head1 METHODS
 
 =over 4
 
 =cut
 
-package AtteanX::Parser::SPARQLTSV 0.034 {
+package AtteanX::Parser::SPARQLTSV 0.001 {
 	use utf8;
 	use Moo;
 	use Attean;
-	use Encode;
 	use Encode qw(decode);
+	use List::MoreUtils qw(zip);
 	use namespace::clean;
 
 	sub canonical_media_type { return "text/tab-separated-values" }
@@ -49,6 +37,12 @@ package AtteanX::Parser::SPARQLTSV 0.034 {
 		return [qw(text/tab-separated-values)];
 	}
 	
+=item C<< file_extensions >>
+
+Returns a list of file extensions that may be parsed with the parser.
+
+=cut
+
 	sub file_extensions { return [qw(tsv)] }
 
 	with 'Attean::API::ResultParser', 'Attean::API::PullParser', 'Attean::API::Parser';
@@ -78,13 +72,9 @@ the data read from the L<IO::Handle> object C<< $fh >>.
 		my $self	= shift;
 		my $fh		= shift;
 		
-		my $parser	= Attean->get_parser('Turtle')->new(lazy_iris => $self->lazy_iris);
+		my $parser	= Attean->get_parser('Turtle')->new();
 
 		my $line	= <$fh>;
-		unless (defined($line)) {
-			die "undefined header line in SPARQL/TSV parser";
-		}
-		
 		chomp($line);
 		my @vars;
 		foreach my $v (split("\t", $line)) {
@@ -104,8 +94,7 @@ the data read from the L<IO::Handle> object C<< $fh >>.
 				my $string	= $strings[$i];
 				if (length($string)) {
 					my $var	= $vars[$i];
-					my $bytes	= encode('UTF-8', $string, Encode::FB_CROAK);
-					my $term	= $parser->parse_term_from_bytes($bytes);
+					my $term	= $parser->parse_term_from_string($string);
 					if ($term) {
 						$binding{ $var }	= $term;
 					}
@@ -114,9 +103,8 @@ the data read from the L<IO::Handle> object C<< $fh >>.
 			return Attean::Result->new( bindings => \%binding );
 		};
 		return Attean::CodeIterator->new(
-			generator	=> $gen,
-			item_type	=> $self->handled_type->role,
-			variables	=> \@vars,
+			generator => $gen,
+			item_type => $self->handled_type->role,
 		);
 	}
 
@@ -139,7 +127,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
