@@ -7,7 +7,7 @@ AtteanX::Parser::SPARQLXML - SPARQL XML Parser
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::SPARQLXML version 0.026
+This document describes AtteanX::Parser::SPARQLXML version 0.001
 
 =head1 SYNOPSIS
 
@@ -28,12 +28,10 @@ This document describes AtteanX::Parser::SPARQLXML version 0.026
 use v5.14;
 use warnings;
 
-package AtteanX::Parser::SPARQLXML 0.026 {
+package AtteanX::Parser::SPARQLXML 0.001 {
 	use XML::SAX::ParserFactory;
 	use Attean;
 	use Moo;
-	use Encode qw(encode);
-	use PerlIO::Layers qw(query_handle);
 	use AtteanX::Parser::SPARQLXML::SAXHandler;
 	
 =item C<< canonical_media_type >>
@@ -79,16 +77,7 @@ the data read from the L<IO::Handle> object C<< $fh >>.
 		my $fh		= shift;
 		my $handler	= AtteanX::Parser::SPARQLXML::SAXHandler->new($self->handler);
 		my $p		= XML::SAX::ParserFactory->parser(Handler => $handler);
-		if (query_handle($fh, 'utf8')) {
-			# the filehandle already has utf-8 decoding applied, but the XML
-			# parser is expecting utf-8 *encoded* bytes, so we need to
-			# re-encode the data before parsing.
-			my $string	= do { local($/); <$fh> };
-			my $data	= encode('UTF-8', $string, Encode::FB_CROAK);
-			$p->parse_string($data);
-		} else {
-			$p->parse_file( $fh );
-		}
+		$p->parse_file( $fh );
 	}
 
 =item C<< parse_cb_from_bytes( $data ) >>
@@ -127,7 +116,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2020 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
