@@ -7,13 +7,14 @@ AtteanX::Parser::SPARQLXML::SAXHandler - XML parser for SPARQL XML Results forma
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::SPARQLXML::SAXHandler version 0.030
+This document describes AtteanX::Parser::SPARQLXML::SAXHandler version 0.001
 
 =head1 STATUS
 
 This module's API and functionality should be considered unstable.
 In the future, this module may change in backwards-incompatible ways,
-or be removed entirely.
+or be removed entirely. If you need functionality that this module provides,
+please L<get in touch|http://www.perlrdf.org/>.
 
 =head1 SYNOPSIS
 
@@ -25,7 +26,7 @@ or be removed entirely.
 
 =cut
 
-package AtteanX::Parser::SPARQLXML::SAXHandler 0.030;
+package AtteanX::Parser::SPARQLXML::SAXHandler 0.001;
 
 use v5.14;
 use warnings;
@@ -48,7 +49,6 @@ my %has_end;
 my %result_count;
 my %result_handlers;
 my %config;
-my %triples;
 
 my %expecting_string	= map { $_ => 1 } qw(boolean bnode uri literal);
 
@@ -89,10 +89,6 @@ sub start_element {
 	if ($expecting_string{ $tag }) {
 		$strings{ $addr }	= '';
 	}
-	
-	if ($tag eq 'triple') {
-		push(@{ $triples{ $addr } }, {});
-	}
 }
 
 =item C<< end_element >>
@@ -152,19 +148,6 @@ sub end_element {
 		} else {
 			$values{ $addr }	= Attean::Literal->new( value => $string );
 		}
-	} elsif ($tag eq 'subject') {
-		my $value	= delete( $values{ $addr } );
-		$triples{ $addr }[-1]{$tag}	= $value;
-	} elsif ($tag eq 'predicate') {
-		my $value	= delete( $values{ $addr } );
-		$triples{ $addr }[-1]{$tag}	= $value;
-	} elsif ($tag eq 'object') {
-		my $value	= delete( $values{ $addr } );
-		$triples{ $addr }[-1]{$tag}	= $value;
-	} elsif ($tag eq 'triple') {
-		my $data	= pop(@{ $triples{ $addr } });
-		my $t	= Attean::Triple->new( %{ $data } );
-		$values{ $addr }	= $t;
 	}
 }
 
@@ -227,7 +210,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2020 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
