@@ -10,63 +10,28 @@ AtteanX::Parser::Turtle - Turtle RDF Parser
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::Turtle version 0.034
+This document describes AtteanX::Parser::Turtle version 0.001
 
 =head1 SYNOPSIS
 
- use Attean;
- my $parser	= AtteanX::Parser::Turtle->new( handler => sub {...}, base => $base_iri );
- 
- # Parse data from a file-handle and handle triples in the 'handler' callback
- $parser->parse_cb_from_io( $fh );
- 
- # Parse the given byte-string, and return an iterator of triples
- my $iter = $parser->parse_iter_from_bytes('<s> <p> 1, 2, 3 .');
- while (my $triple = $iter->next) {
-   print $triple->as_string;
- }
+ use AtteanX::Parser::Turtle;
+ my $parser	= AtteanX::Parser::Turtle->new( handler => sub {...} );
+ $parser->parse_cb_from_io( $fh, $base_uri );
 
 =head1 DESCRIPTION
 
 This module implements a parser for the Turtle RDF format.
 
-=head1 ROLES
-
-This class consumes L<Attean::API::Parser>, L<Attean::API::PushParser>,
-<Attean::API::AbbreviatingParser>, and <Attean::API::TripleParser>.
-
-=head1 ATTRIBUTES
-
-=over 4
-
-=item C<< canonical_media_type >>
-
-=item C<< media_types >>
-
-=item C<< file_extensions >>
-
-=item C<< canonicalize >>
-
-A boolean indicating whether term values should be canonicalized during parsing.
-
-=item C<< blank_nodes >>
-
-=item C<< has_blank_nodes_map >>
-
-=back
-
 =head1 METHODS
 
 =over 4
 
 =cut
 
-package AtteanX::Parser::Turtle 0.034 {
+package AtteanX::Parser::Turtle 0.001 {
 	use Moo;
-	use Types::Standard qw(Bool HashRef ArrayRef HashRef Str Maybe InstanceOf ConsumerOf);
-	use Types::Namespace qw( NamespaceMap );
+	use Types::Standard qw(Bool ArrayRef HashRef Str Maybe InstanceOf);
 	use utf8;
-	use Carp qw(carp);
 	use Encode qw(encode);
 	use Scalar::Util qw(blessed);
 	use AtteanX::Parser::Turtle::Constants;
@@ -75,26 +40,37 @@ package AtteanX::Parser::Turtle 0.034 {
 	use Attean::API::Parser;
 	use namespace::clean;
 
+=item C<< canonical_media_type >>
+
+Returns the canonical media type for Turtle: text/turtle.
+
+=cut
+
 	sub canonical_media_type { return "text/turtle" }
 
+=item C<< media_types >>
+
+Returns a list of media types that may be parsed with the Turtle parser:
+text/turtle.
+
+=cut
+
 	sub media_types {
 		return [qw(application/x-turtle application/turtle text/turtle)];
 	}
 
-	sub file_extensions { return [qw(ttl)] }
+=item C<< file_extensions >>
 
-	has 'canonicalize'	=> (is => 'rw', isa => Bool, default => 0);
-	has '_map' => (is => 'ro', isa => HashRef[Str], default => sub { +{} });
-
-=item C<< has_namespaces >>
-
-Returns true if the parser has a namespace map, false otherwise.
+Returns a list of file extensions that may be parsed with the parser.
 
 =cut
 
-	has 'namespaces' => (is => 'rw', isa => Maybe[NamespaceMap], predicate => 'has_namespaces');
-	has 'blank_nodes'	=> (is => 'ro', isa => HashRef[ConsumerOf['Attean::API::Blank']], predicate => 'has_blank_nodes_map', default => sub { +{} });
-	has	'_stack'	=> (
+	sub file_extensions { return [qw(ttl)] }
+
+	has 'canonicalize'	=> (is => 'rw', isa => Bool, default => 0);
+	has 'map' => (is => 'ro', isa => HashRef[Str], default => sub { +{} });
+	has 'namespaces' => (is => 'rw', isa => Maybe[InstanceOf['URI::NamespaceMap']], predicate => 'has_namespaces');
+	has	'stack'	=> (
 		is => 'ro',
 		isa => ArrayRef,
 		default => sub { [] },
@@ -104,7 +80,6 @@ Returns true if the parser has a namespace map, false otherwise.
 	with 'Attean::API::TripleParser';
 	with 'Attean::API::AbbreviatingParser';
 	with 'Attean::API::PushParser';
-	with 'Attean::API::CDTBlankNodeMappingParser';
 	
 	my $RDF	= 'http://www.w3.org/1999/02/22-rdf-syntax-ns#';
 	my $XSD	= 'http://www.w3.org/2001/XMLSchema#';
@@ -148,20 +123,15 @@ the data read from the UTF-8 encoded byte string C<< $data >>.
 		$self->_parse($l);
 	}
 
-=item C<< parse_term_from_bytes ( $bytes ) >>
-
-=item C<< parse_node ( $bytes ) >>
+=item C<< parse_node ( $string, $base ) >>
 
 Returns the Attean::API::Term object corresponding to the node whose N-Triples
-serialization is found at the beginning of C<< $bytes >>.
+serialization is found at the beginning of C<< $string >>.
 
 =cut
 
-	sub parse_term_from_bytes {
+	sub parse_term_from_string {
 		my $self	= shift;
-		unless (ref($self)) {
-			$self	= $self->new();
-		}
 		return $self->parse_node(@_);
 	}
 	
@@ -171,7 +141,7 @@ serialization is found at the beginning of C<< $bytes >>.
 		my %args	= @_;
 	
 		open(my $fh, '<:encoding(UTF-8)', \$string);
-		my $l	= AtteanX::Parser::Turtle::Lexer->new(file => $fh, %args);
+		my $l	= AtteanX::Parser::Turtle::Lexer->new($fh);
 		my $t = $self->_next_nonws($l);
 		my $node	= $self->_object($l, $t);
 		return $node;
@@ -191,14 +161,14 @@ serialization is found at the beginning of C<< $bytes >>.
 	sub _unget_token {
 		my $self	= shift;
 		my $t		= shift;
-		push(@{ $self->_stack }, $t);
+		push(@{ $self->stack }, $t);
 # 		push(@{ $self->{ stack } }, $t);
 	}
 
 	sub _next_nonws {
 		my $self	= shift;
-		if (scalar(@{ $self->_stack })) {
-			return pop(@{ $self->_stack });
+		if (scalar(@{ $self->stack })) {
+			return pop(@{ $self->stack });
 		}
 		my $l		= shift;
 		while (1) {
@@ -232,7 +202,7 @@ serialization is found at the beginning of C<< $bytes >>.
 		my $t		= shift;
 		my $type	= $t->type;
 	# 		when (WS) {}
-		if ($type == TURTLEPREFIX or $type == PREFIX) {
+		if ($type == PREFIX or $type == SPARQLPREFIX) {
 			$t	= $self->_get_token_type($l, PREFIXNAME);
 			use Data::Dumper;
 			unless (defined($t->value)) {
@@ -247,16 +217,16 @@ serialization is found at the beginning of C<< $bytes >>.
 			if ($self->has_base) {
 				$args{base}	= $self->base;
 			}
-			my $r	= $self->new_iri(%args);
+			my $r	= Attean::IRI->new(%args);
 			my $iri	= $r->as_string;
-			if ($type == TURTLEPREFIX) {
+			if ($type == PREFIX) {
 				$t	= $self->_get_token_type($l, DOT);
 	# 			$t	= $self->_next_nonws($l);
 	# 			if ($t and $t->type != DOT) {
 	# 				$self->_unget_token($t);
 	# 			}
 			}
-			$self->_map->{$name}	= $iri;
+			$self->map->{$name}	= $iri;
 			if ($self->has_namespaces) {
 				my $ns	= $self->namespaces;
 				unless ($ns->namespace_uri($name)) {
@@ -264,15 +234,15 @@ serialization is found at the beginning of C<< $bytes >>.
 				}
 			}
 		}
-		elsif ($type == TURTLEBASE or $type == BASE) {
+		elsif ($type == BASE or $type == SPARQLBASE) {
 			$t	= $self->_get_token_type($l, IRI);
 			my %args	= (value => $t->value);
 			if ($self->has_base) {
 				$args{base}	= $self->base;
 			}
-			my $r	= $self->new_iri(%args);
+			my $r	= Attean::IRI->new(%args);
 			my $iri	= $r->as_string;
-			if ($type == TURTLEBASE) {
+			if ($type == BASE) {
 				$t	= $self->_get_token_type($l, DOT);
 	# 			$t	= $self->_next_nonws($l);
 	# 			if ($t and $t->type != DOT) {
@@ -296,9 +266,7 @@ serialization is found at the beginning of C<< $bytes >>.
 		# subject
 		my $subj;
 		my $bnode_plist	= 0;
-		if ($type == LTLT) {
-			$subj	= $self->_quotedTriple($l);
-		} elsif ($type == LBRACKET) {
+		if ($type == LBRACKET) {
 			$bnode_plist	= 1;
 			$subj	= Attean::Blank->new();
 			my $t	= $self->_next_nonws($l);
@@ -310,7 +278,7 @@ serialization is found at the beginning of C<< $bytes >>.
 		} elsif ($type == LPAREN) {
 			my $t	= $self->_next_nonws($l);
 			if ($t->type == RPAREN) {
-				$subj	= Attean::IRI->new(value => "http://www.w3.org/1999/02/22-rdf-syntax-ns#nil", lazy => 1);
+				$subj	= Attean::IRI->new('http://www.w3.org/1999/02/22-rdf-syntax-ns#nil');
 			} else {
 				$subj	= Attean::Blank->new();
 				my @objects	= $self->_object($l, $t);
@@ -345,86 +313,6 @@ serialization is found at the beginning of C<< $bytes >>.
 		}
 	}
 
-	sub _quotedTriple {
-		my $self	= shift;
-		my $l		= shift;
-		my $subj	= $self->_qtSubject($l);
-
-		my $t		= $self->_next_nonws($l);
-		my $type	= $t->type;
-		unless ($type==IRI or $type==PREFIXNAME or $type==A) {
-			$self->_throw_error("Expecting verb but got " . decrypt_constant($type), $t, $l);
-		}
-		my $pred	= $self->_token_to_node($t);
-		my $obj		= $self->_qtObject($l, $self->_next_nonws($l));
-		$self->_get_token_type($l, GTGT);
-		my $triple	= Attean::Triple->new($subj, $pred, $obj);
-		return $triple;
-	}
-	
-	sub _qtSubject {
-		my $self	= shift;
-		my $l		= shift;
-		my $t		= $self->_next_nonws($l);
-		my $type	= $t->type;
-
-		my $subj;
-		if ($type == LTLT) {
-			$subj	= $self->_quotedTriple($l);
-		} elsif ($type == LBRACKET) {
-			$self->_get_token_type($l, RBRACKET);
-			return Attean::Blank->new();
-		} elsif (not($type==IRI or $type==PREFIXNAME or $type==BNODE)) {
-			$self->_throw_error("Expecting resource or bnode but got " . decrypt_constant($type), $t, $l);
-		} else {
-			$subj	= $self->_token_to_node($t);
-		}
-		return $subj;
-	}
-
-	sub _qtObject {
-		my $self	= shift;
-		my $l		= shift;
-		my $t		= shift;
-		my $tcopy	= $t;
-		my $obj;
-		my $type	= $t->type;
-		if ($type == LTLT) {
-			$obj	= $self->_quotedTriple($l);
-		} elsif ($type == LBRACKET) {
-			$self->_get_token_type($l, RBRACKET);
-			return Attean::Blank->new();
-		} elsif (not($type==IRI or $type==PREFIXNAME or $type==STRING1D or $type==STRING3D or $type==STRING1S or $type==STRING3S or $type==BNODE or $type==INTEGER or $type==DECIMAL or $type==DOUBLE or $type==BOOLEAN)) {
-			$self->_throw_error("Expecting object but got " . decrypt_constant($type), $t, $l);
-		} else {
-			if ($type==STRING1D or $type==STRING3D or $type==STRING1S or $type==STRING3S) {
-				my $value	= $t->value;
-				my $t		= $self->_next_nonws($l);
-				my $dt;
-				my $lang;
-				if ($t) {
-					if ($t->type == HATHAT) {
-						my $t		= $self->_next_nonws($l);
-						if ($t->type == IRI or $t->type == PREFIXNAME) {
-							$dt	= $self->_token_to_node($t);
-						}
-					} elsif ($t->type == LANG) {
-						$lang	= $t->value;
-					} else {
-						$self->_unget_token($t);
-					}
-				}
-				my %args	= (value => $value);
-				$args{language}	= $lang if (defined($lang));
-				$args{datatype}	= $dt if (defined($dt));
-				$obj	= $self->new_literal(%args);
-			} else {
-				$obj	= $self->_token_to_node($t, $type);
-			}
-		}
-		return $obj;
-	}
-	
 	sub _assert_list {
 		my $self	= shift;
 		my $subj	= shift;
@@ -432,9 +320,9 @@ serialization is found at the beginning of C<< $bytes >>.
 		my $head	= $subj;
 		while (@objects) {
 			my $obj	= shift(@objects);
-			$self->_assert_triple($head, Attean::IRI->new(value => "${RDF}first", lazy => 1), $obj);
-			my $next	= scalar(@objects) ? Attean::Blank->new() : Attean::IRI->new(value => "${RDF}nil", lazy => 1);
-			$self->_assert_triple($head, Attean::IRI->new(value => "${RDF}rest", lazy => 1), $next);
+			$self->_assert_triple($head, Attean::IRI->new("${RDF}first"), $obj);
+			my $next	= scalar(@objects) ? Attean::Blank->new() : Attean::IRI->new("${RDF}nil");
+			$self->_assert_triple($head, Attean::IRI->new("${RDF}rest"), $next);
 			$head		= $next;
 		}
 	}
@@ -484,7 +372,7 @@ serialization is found at the beginning of C<< $bytes >>.
 			my $t		= $self->_next_nonws($l);
 			last unless ($t);
 			my $obj		= $self->_object($l, $t);
-			$self->_assert_triple_with_optional_annotation($l, $subj, $pred, $obj);
+			$self->_assert_triple($subj, $pred, $obj);
 		
 			$t	= $self->_next_nonws($l);
 			if ($t and $t->type == COMMA) {
@@ -496,24 +384,6 @@ serialization is found at the beginning of C<< $bytes >>.
 		}
 	}
 
-	sub _assert_triple_with_optional_annotation {
-		my $self	= shift;
-		my $l		= shift;
-		my $subj	= shift;
-		my $pred	= shift;
-		my $obj		= shift;
-		my $qt		= $self->_assert_triple($subj, $pred, $obj);
-		
-		my $t	= $self->_next_nonws($l);
-		if ($t->type != LANNOT) {
-			$self->_unget_token($t);
-			return;
-		}
-		
-		$self->_predicateObjectList( $l, $qt );
-		$self->_get_token_type($l, RANNOT);
-	}
-	
 	sub _assert_triple {
 		my $self	= shift;
 		my $subj	= shift;
@@ -525,7 +395,6 @@ serialization is found at the beginning of C<< $bytes >>.
 	
 		my $t		= Attean::Triple->new($subj, $pred, $obj);
 		$self->handler->($t);
-		return $t;
 	}
 
 
@@ -536,9 +405,7 @@ serialization is found at the beginning of C<< $bytes >>.
 		my $tcopy	= $t;
 		my $obj;
 		my $type	= $t->type;
-		if ($type==LTLT) {
-			return $self->_quotedTriple($l);
-		} elsif ($type==LBRACKET) {
+		if ($type==LBRACKET) {
 			$obj	= Attean::Blank->new();
 			my $t	= $self->_next_nonws($l);
 			unless ($t) {
@@ -555,7 +422,7 @@ serialization is found at the beginning of C<< $bytes >>.
 				$self->_throw_error("Expecting object but got only opening paren", $tcopy, $l);
 			}
 			if ($t->type == RPAREN) {
-				$obj	= Attean::IRI->new(value => "http://www.w3.org/1999/02/22-rdf-syntax-ns#nil", lazy => 1);
+				$obj	= Attean::IRI->new('http://www.w3.org/1999/02/22-rdf-syntax-ns#nil');
 			} else {
 				$obj	= Attean::Blank->new();
 				my @objects	= $self->_object($l, $t);
@@ -593,7 +460,7 @@ serialization is found at the beginning of C<< $bytes >>.
 				my %args	= (value => $value);
 				$args{language}	= $lang if (defined($lang));
 				$args{datatype}	= $dt if (defined($dt));
-				$obj	= $self->new_literal(%args);
+				$obj	= Attean::Literal->new(%args);
 			} else {
 				$obj	= $self->_token_to_node($t, $type);
 			}
@@ -606,7 +473,7 @@ serialization is found at the beginning of C<< $bytes >>.
 		my $t		= shift;
 		my $type	= shift || $t->type;
 		if ($type eq A) {
-			state $rdftype	= Attean::IRI->new(value => "${RDF}type", lazy => 1);
+			state $rdftype	= Attean::IRI->new("${RDF}type");
 			return $rdftype;
 		}
 		elsif ($type eq IRI) {
@@ -615,7 +482,7 @@ serialization is found at the beginning of C<< $bytes >>.
 			my $iri;
 			if ($self->has_base) {
 				$args{base}	= $self->base;
-				my $iri	= $self->new_iri(%args);
+				my $iri	= Attean::IRI->new(%args);
 				return $iri;
 			}
 			
@@ -623,7 +490,7 @@ serialization is found at the beginning of C<< $bytes >>.
 			 if (my $n = $cache{$value}) {
 				return $n;
 			} else {
-				my $iri	= $self->new_iri(%args);
+				my $iri	= Attean::IRI->new(%args);
 				if (rand() < 0.02) {
 					# clear out the cache roughly every 50 IRIs
 					%cache	= ();
@@ -633,38 +500,36 @@ serialization is found at the beginning of C<< $bytes >>.
 			}
 		}
 		elsif ($type eq INTEGER) {
-			return $self->new_literal(value => $t->value, datatype => Attean::IRI->new(value => "${XSD}integer", lazy => 1));
+			return Attean::Literal->new(value => $t->value, datatype => Attean::IRI->new("${XSD}integer"));
 		}
 		elsif ($type eq DECIMAL) {
-			return $self->new_literal(value => $t->value, datatype => Attean::IRI->new(value => "${XSD}decimal", lazy => 1));
+			return Attean::Literal->new(value => $t->value, datatype => Attean::IRI->new("${XSD}decimal"));
 		}
 		elsif ($type eq DOUBLE) {
-			return $self->new_literal(value => $t->value, datatype => Attean::IRI->new(value => "${XSD}double", lazy => 1));
+			return Attean::Literal->new(value => $t->value, datatype => Attean::IRI->new("${XSD}double"));
 		}
 		elsif ($type eq BOOLEAN) {
-			return $self->new_literal(value => $t->value, datatype => Attean::IRI->new(value => "${XSD}boolean", lazy => 1));
+			return Attean::Literal->new(value => $t->value, datatype => Attean::IRI->new("${XSD}boolean"));
 		}
 		elsif ($type eq PREFIXNAME) {
 			my ($ns, $local)	= @{ $t->args };
 			$ns		=~ s/:$//;
-			unless (exists $self->_map->{$ns}) {
+			unless (exists $self->map->{$ns}) {
 				$self->_throw_error("Use of undeclared prefix '$ns'", $t);
 			}
-			my $prefix			= $self->_map->{$ns};
+			my $prefix			= $self->map->{$ns};
 			no warnings 'uninitialized';
-			my $iri				= $self->new_iri("${prefix}${local}");
+			my $iri				= Attean::IRI->new("${prefix}${local}");
 			return $iri;
 		}
 		elsif ($type eq BNODE) {
-			my $b	= Attean::Blank->new($t->value);
-			$self->blank_nodes->{$t->value}	= $b;
-			return $b;
+			return Attean::Blank->new($t->value);
 		}
 		elsif ($type eq STRING1D) {
-			return $self->new_literal($t->value);
+			return Attean::Literal->new($t->value);
 		}
 		elsif ($type eq STRING1S) {
-			return $self->new_literal($t->value);
+			return Attean::Literal->new($t->value);
 		}
 		else {
 			$self->_throw_error("Converting $type to node not implemented", $t);
@@ -704,7 +569,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
