@@ -7,7 +7,7 @@ AtteanX::Parser::Turtle::Constants - Constant definitions for use in parsing Tur
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::Turtle::Constants version 0.034
+This document describes AtteanX::Parser::Turtle::Constants version 0.001
 
 =head1 SYNOPSIS
 
@@ -19,48 +19,45 @@ This document describes AtteanX::Parser::Turtle::Constants version 0.034
 
 =cut
 
-package AtteanX::Parser::Turtle::Constants 0.034 {
+package AtteanX::Parser::Turtle::Constants 0.001 {
 	use v5.14;
 	use warnings;
 
+	our $VERSION;
 	our @EXPORT;
 	BEGIN {
+		$VERSION				= '0.001';
 		@EXPORT = qw(
-			A
-			BASE
-			BNODE
-			BOOLEAN
-			COMMA
-			COMMENT
-			DECIMAL
-			DOT
-			DOUBLE
-			EQUALS
-			HATHAT
-			INTEGER
-			IRI
-			LANG
-			LBRACE
 			LBRACKET
-			LPAREN
-			GRAPH
-			PREFIX
-			PREFIXNAME
-			RBRACE
 			RBRACKET
+			LPAREN
 			RPAREN
+			DOT
 			SEMICOLON
-			STRING1D
-			STRING1S
+			COMMA
+			HATHAT
+			A
+			BOOLEAN
+			PREFIXNAME
+			IRI
+			BNODE
+			DOUBLE
+			DECIMAL
+			INTEGER
+			WS
+			COMMENT
 			STRING3D
 			STRING3S
-			TURTLEBASE
-			TURTLEPREFIX
-			GTGT
-			LTLT
-			LANNOT
-			RANNOT
-			WS
+			STRING1D
+			STRING1S
+			BASE
+			PREFIX
+			SPARQLBASE
+			SPARQLPREFIX
+			LANG
+			LBRACE
+			RBRACE
+			EQUALS
 			decrypt_constant
 		)
 	};
@@ -106,7 +103,7 @@ Toby Inkster C<< <tobyink@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Toby Inkster. This
+Copyright (c) 2012 Toby Inkster. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
