@@ -4,7 +4,7 @@ AtteanX::Serializer::NTriples - N-Triples Serializer
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::NTriples version 0.034
+This document describes AtteanX::Serializer::NTriples version 0.001
 
 =head1 SYNOPSIS
 
@@ -14,60 +14,28 @@ This document describes AtteanX::Serializer::NTriples version 0.034
 
 =head1 DESCRIPTION
 
-Serializes triples into the RDF 1.1 N-Triples format.
-
-=head1 ATTRIBUTES
-
-=over 4
-
-=item C<< canonical_media_type >>
-
-=item C<< file_extensions >>
-
-=back
+...
 
 =head1 METHODS
 
 =over 4
 
-=item C<< serialize_iter_to_io( $fh, $iterator ) >>
-
-=item C<< serialize_iter_to_bytes( $fh ) >>
-
 =cut
 
 use v5.14;
 use warnings;
 
-package AtteanX::Serializer::NTriples 0.034 {
+package AtteanX::Serializer::NTriples 0.001 {
 	use Moo;
 	use Types::Standard qw(Str ArrayRef);
 	use Encode qw(encode);
 	use Attean::ListIterator;
-	use List::Util qw(any);
+	use List::MoreUtils qw(any);
 	use namespace::clean;
 
 	extends 'AtteanX::Serializer::NTuples';
 	has 'canonical_media_type' => (is => 'ro', isa => Str, init_arg => undef, default => 'application/n-triples');
-
-=item C<< media_types >>
-
-Returns a list of media types that identify the format produced by this serializer.
-
-=cut
-
-	sub media_types {
-		return [qw(application/n-triples text/plain)];
-	}
-
-=item C<< file_extensions >>
-
-Returns a list of file extensions associated with the serialized format.
-
-=cut
-
-	sub file_extensions { return [qw(nt)] };
-	
+	has 'media_types' => (is => 'ro', isa => ArrayRef[Str], init_arg => undef, default => sub { ['application/n-triples'] });
 	with 'Attean::API::TripleSerializer';
 	with 'Attean::API::AppendableSerializer';
 }
@@ -83,17 +51,13 @@ __END__
 Please report any bugs or feature requests to through the GitHub web interface
 at L<https://github.com/kasei/perlrdf/issues>.
 
-=head1 SEE ALSO
-
-L<https://www.w3.org/TR/n-triples/>
-
 =head1 AUTHOR
 
 Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
