@@ -4,13 +4,13 @@ AtteanX::Serializer::NTuples - Shared functionality for N-Triples and N-Quads se
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::NTuples version 0.034
+This document describes AtteanX::Serializer::NTuples version 0.001
 
 =head1 SYNOPSIS
 
  use Attean;
- my $serializer = Attean->get_serializer('NTriples')->new();
- $serializer->serialize_iter_to_io( $io, $fh );
+ my $parser = Attean->get_serializer('NTriples')->new();
+ $parser->serialize_iter_to_io( $fh );
 
 =head1 DESCRIPTION
 
@@ -25,11 +25,11 @@ This document describes AtteanX::Serializer::NTuples version 0.034
 use v5.14;
 use warnings;
 
-package AtteanX::Serializer::NTuples 0.034 {
+package AtteanX::Serializer::NTuples 0.001 {
 	use Moo;
 	use Encode qw(encode);
 	use Attean::ListIterator;
-	use List::Util qw(any);
+	use List::MoreUtils qw(any);
 	use namespace::clean;
 	
 =item C<< serialize_iter_to_io( $fh, $iterator ) >>
@@ -50,7 +50,7 @@ L<IO::Handle> object C<< $fh >>.
 		return;
 	}
 	
-=item C<< serialize_iter_to_bytes( $iterator ) >>
+=item C<< serialize_iter_to_bytes( $fh, $iterator ) >>
 
 Serializes the L<Attean::API::Binding> objects from C<< $iterator >>
 and returns the serialization as a UTF-8 encoded byte string.
@@ -86,7 +86,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
