@@ -4,7 +4,7 @@ AtteanX::Serializer::SPARQLTSV - SPARQL Results TSV Serializer
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::SPARQLTSV version 0.034
+This document describes AtteanX::Serializer::SPARQLTSV version 0.001
 
 =head1 SYNOPSIS
 
@@ -16,16 +16,6 @@ This document describes AtteanX::Serializer::SPARQLTSV version 0.034
 
 ...
 
-=head1 ATTRIBUTES
-
-=over 4
-
-=item C<< canonical_media_type >>
-
-=item C<< file_extensions >>
-
-=back
-
 =head1 METHODS
 
 =over 4
@@ -35,34 +25,17 @@ This document describes AtteanX::Serializer::SPARQLTSV version 0.034
 use v5.14;
 use warnings;
 
-package AtteanX::Serializer::SPARQLTSV 0.034 {
+package AtteanX::Serializer::SPARQLTSV 0.001 {
 	use Moo;
 	use Types::Standard qw(Str ArrayRef);
 	use Encode qw(encode);
 	use Scalar::Util qw(blessed);
 	use Attean::ListIterator;
-	use List::Util qw(any);
+	use List::MoreUtils qw(any);
 	use namespace::clean;
 
-	has 'canonical_media_type' => (is => 'ro', isa => Str, init_arg => undef, default => 'text/tab-separated-values');
-
-=item C<< media_types >>
-
-Returns a list of media types that identify the format produced by this serializer.
-
-=cut
-
-	sub media_types {
-		return [qw(text/tab-separated-values)];
-	}
-
-=item C<< file_extensions >>
-
-Returns a list of file extensions associated with the serialized format.
-
-=cut
-
-	sub file_extensions { return [qw(tsv)] };
+	has 'canonical_media_type' => (is => 'ro', isa => Str, init_arg => undef, default => 'text/csv');
+	has 'media_types' => (is => 'ro', isa => ArrayRef[Str], init_arg => undef, default => sub { ['text/csv'] });
 	
 =item C<< serialize_iter_to_io( $fh, $iterator ) >>
 
@@ -75,18 +48,19 @@ L<IO::Handle> object C<< $fh >>.
 		my $self	= shift;
 		my $io		= shift;
 		my $iter	= shift;
-		
-		my @vars	= @{ $iter->variables };
-		$io->print(join("\t", map { "?$_" } @vars) . "\n");
-		
+		my $first	= 1;
 		while (my $t = $iter->next()) {
-			my @strings	= map { blessed($_) ? $_->ntriples_string : '' } map { $t->value($_) } @vars;
+			if ($first) {
+				$io->print(join("\t", map { "?$_" } $t->variables) . "\n");
+				$first	= 0;
+			}
+			my @strings	= map { blessed($_) ? $_->ntriples_string : '' } $t->values;
 			$io->print(join("\t", @strings) . "\n");
 		}
 		return;
 	}
 	
-=item C<< serialize_iter_to_bytes( $iterator ) >>
+=item C<< serialize_iter_to_bytes( $fh, $iterator ) >>
 
 Serializes the L<Attean::API::Binding> objects from C<< $iterator >>
 and returns the serialization as a UTF-8 encoded byte string.
@@ -97,12 +71,8 @@ and returns the serialization as a UTF-8 encoded byte string.
 		my $self	= shift;
 		my $iter	= shift;
 		my $data	= '';
-
-		my @vars	= @{ $iter->variables };
-		$data		.= join("\t", map { "?$_" } @vars) . "\n";
-		
 		while (my $t = $iter->next()) {
-			my @strings	= map { blessed($_) ? $_->ntriples_string : '' } map { $t->value($_) } @vars;
+			my @strings	= map { blessed($_) ? $_->ntriples_string : '' } $t->values;
 			my $str		= join("\t", @strings);
 			$data		.= $str . "\n";
 		}
@@ -129,7 +99,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
